/*====================PROCEDIMENTO GERA_DADOS_FINANCEIRO========================

   PROCEDIMENTO RESPONSVEL PELA CRIAO DE TODAS AS INFORMAES FINANCEIRAS
   (CONTAS, BOLETOS E AJUSTES) NECESSRIAS AO SE LANAR / APROVAR
   NOTAS FISCAIS DE ENTRADA/SADA
   -------
   ENTRADA
   -------
      O PROCEDIMENTO RECEBE OS SEGUINTES PARMETROS :

      - P_CDFILIAL   : CDIGO DA FILIAL DE LANAMENTO DA NOTA FISCAL (CHAVE DA NOTA)
      - P_NRLANCTONF : NMERO DE LANAMENTO DA NOTA FISCAL (CHAVE DA NOTA)
      - P_CDFILIPROC : FILIAL DE PROCESSAMENTO DA OPERAO
      - P_IDOPERACAO : 'L' - LANAMENTO DA NOTA FISCAL
                       'A' - APROVAO DA NOTA FISCAL
                       'T' - TRANSFERNCIA DE NOTA FISCAL ELETRNICA (SEM GERAO DE BOLETO)

   -----
   SADA
   -----
      O PROCEDIMENTO POSSUI PARMETRO DE RETORNO (P_RESULTADO) PARA RECEBER AS EVENTUAIS MENSAGENS
      DE ERRO DA EXECUO DO PROCEDIMENTO. QUANDO O RETORNO NO FOR VAZIO SEU VALOR  UMA MENSAGEM DE ERRO

   ------------------
   MTODOS AUXILIARES
   ------------------
      PROCEDURE BOLFORN_JA_EXISTENTE : PROCEDIMENTO QUE BUSCA O BOLETO DO FORNECEDOR PARA A DATA INFORMADA
      PROCEDURE GERA_AJUSTE_BONI_PAG : GERA AJUSTES DE BONIFICAO NAS CONTAS DO FORNECEDOR
      PROCEDURE MONTA_HISTORICO      : MONTA HISTRICO PADRO, SUBSTITUINDO MNEUMNICOS
      FUNCTION VD_CENTCUSTFIL        : VERIFICA SE O CENTRO DE CUSTO EST RELACIONADO  FILIAL
      PROCEDURE GERA_RATEIO_PAG      : GERA RATEIO FINANCEIRO PARA AS CONTAS A PAGAR
      PROCEDURE GERA_RATEIO_REC      : GERA RATEIO FINANCEIRO PARA AS CONTAS A RECEBER
      PROCEDURE VERI_NF_RELAC_AF     : VERIFICA NOTA FISCAL RELACIONADA  AF

   -----------------
   MENSAGENS DE ERRO
   -----------------

   NF_NOT_EXIST : NOTA FISCAL NO ENCONTRADA NA BASE DE DADOS
   CNT_SUP_VRORC : CONTA A SER INSERIDA SUPERA O VALOR ORADO PARA O MS
   INV_TP_OP : TIPO DE OPERAO DE GERAO INVLIDA
   NOT_CENTCUSTFIL_ + CDCENTCUST + CDFILIAL : CENTRO DE CUSTO (CDCENTCUST) NO CADASTRADO PARA A FILIAL (CDFILIAL)

   -----------------
   DEBUGAR PROCEDURE
   -----------------

   RAISERROR('', 16,1);
*/

IF EXISTS (SELECT
              *
           FROM SYSOBJECTS O, SYSUSERS U
           WHERE
              O.NAME = 'GERA_DADOS_FINANCEIRO' AND
              TYPE   = 'P'                     AND
              U.UID  = O.UID                   AND
              U.NAME = USER)

DROP PROCEDURE GERA_DADOS_FINANCEIRO
GO
CREATE PROCEDURE GERA_DADOS_FINANCEIRO(@P_CDFILIAL   VARCHAR(4),
                                       @P_NRLANCTONF VARCHAR(10),
                                       @P_CDFILIPROC VARCHAR(4),
                                       @P_IDOPERACAO VARCHAR(1),
                                       @P_RESULTADO VARCHAR(2000) OUTPUT)
AS
   /*CONTADOR GENRICO*/
   DECLARE @V_COUNT DOUBLE PRECISION;
   DECLARE @V_QTCONTA DOUBLE PRECISION;
   DECLARE @V_ROW_COUNT DOUBLE PRECISION;
   /*VARIVEIS DA ROTINA DE DESCONTO DE BONIFICAO*/
   DECLARE @V_FATOR DOUBLE PRECISION;
   DECLARE @V_CHAVE VARCHAR(20);
   /*VARIVEIS DA ROTINA DE RATEIO DA CONTA A PAGAR*/
   DECLARE @V_NRPARCELA DOUBLE PRECISION;
   DECLARE @V_VRPARCELA NUMERIC(15,2);
   DECLARE @V_VRACUMULADO NUMERIC(15,2);
   DECLARE @V_CDFILIAL VARCHAR(4);
   DECLARE @V_CDCENTCUST VARCHAR(4);
   DECLARE @V_VRRATEIOCTB NUMERIC(15,2);
   DECLARE @V_RAT_CDTPCONTA VARCHAR(6);
   DECLARE @V_RAT_CDCENTCUST VARCHAR(4);
   DECLARE @V_RAT_CDFIRATTPCT VARCHAR(4);
   DECLARE @V_RAT_CDFILIAL VARCHAR(4);
   DECLARE @V_RAT_VRPERATTPCT NUMERIC(15,2);
   DECLARE @V_MENSERRO VARCHAR(2000);
   DECLARE @V_RAT_CDFILIALNF VARCHAR(4);
   DECLARE @V_RAT_NRLANCTONF VARCHAR(10);
   /*SEQUENCIAL*/
   DECLARE @V_SEQUENCIAL DOUBLE PRECISION;
   /* VARIVEIS PARA OS DADOS DA NOTA FISCAL */
   DECLARE @V_CDEMPRESA VARCHAR(2);
   DECLARE @V_VRNOTAFISC NUMERIC(15,2);
   DECLARE @V_ORIGDESTNF VARCHAR(1);
   DECLARE @V_IDDOCFINANC VARCHAR(1);
   DECLARE @V_ENTRSAIDOP VARCHAR(1);
   DECLARE @V_CDFILIRECE VARCHAR(4);
   DECLARE @V_CDFILIEMIT VARCHAR(4);
   DECLARE @V_CDFILIEMIRECE VARCHAR(4);
   DECLARE @V_DTEMISSAO DATETIME;
   DECLARE @V_DTENTRSAID DATETIME;
   DECLARE @V_CDTIPOOPER VARCHAR(2);
   DECLARE @V_CDFORNECED VARCHAR(21);
   DECLARE @V_CDCLIENTE VARCHAR(21);
   DECLARE @V_CLIEFORN VARCHAR(21);
   DECLARE @V_IDSISTEMA VARCHAR(3);
   DECLARE @V_CDINSESTA VARCHAR(16);
   DECLARE @V_IDSTATUS VARCHAR(1);
   DECLARE @V_NRLANCCONT VARCHAR(10);
   /*TOTAL DE IMPOSTO RETIDO*/
   DECLARE @V_VRIMPORETI NUMERIC(15,2);
   DECLARE @V_VRDESCBONI NUMERIC(15,2);
   /* VARIVEIS PARA GERAO DE VENCIMENTOS */
   /*DADOS DO VENCIMENTO*/
   DECLARE @V_VRVENCIMENTO NUMERIC(15,2);
   /*VALOR ACUMULADO DE VENCIMENTOS*/
   DECLARE @V_VRVENCACUM NUMERIC(15,2);
   /*VALOR DO IMPOSTO REFERENTE AO VENCIMENTO*/
   DECLARE @V_VRIMPOSTO NUMERIC(15,2);
   /* VARIVEIS PARA GERAO DE BOLETO */
   /*VALOR PERCENTUAL DE MORA*/
   DECLARE @V_VRPERMORA NUMERIC(15,2);
   /*VALOR PERCENTUAL DE MULTA*/
   DECLARE @V_VRPERMULTA NUMERIC(15,2);
   /*TIPO DE CONTA A PAGAR DA AF*/
   DECLARE @V_TPCONTAPAG_AF VARCHAR(6);
   /*COUNT OS TIPO DE CONTAS DA AF RELACIONADA DA NF */
   DECLARE @V_COUNTTPCONTA_AF  DOUBLE PRECISION;
   /*TIPO DE BAIXA A PAGAR*/
   DECLARE @V_CDTPBAIXAPAG VARCHAR(2);
   /*TIPO DE BAIXA A RECEBER*/
   DECLARE @V_CDTPBAIXAREC VARCHAR(2);
   /*TIPO DO TIPO DE BAIXA*/
   DECLARE @V_IDBAIXAUTIL VARCHAR(1);
   /*CONTA CORRENTE*/
   DECLARE @V_CDREDUCONT VARCHAR(3);
   /*TIPO DE CONTA A PAGAR*/
   DECLARE @V_CDTPCTPAGAR VARCHAR(6);
   /*TIPO DE CONTA A RECEBER*/
   DECLARE @V_CDTPCTRECEB VARCHAR(6);
   /*CLASSIFICAO FINANCEIRA*/
   DECLARE @V_CDCLASSFINA VARCHAR(6);
   /*FILIAL DO BOLETO*/
   DECLARE @V_CDFILIBOL VARCHAR(4);
   /*NMERO DO BOLETO*/
   DECLARE @V_NRLANBOL VARCHAR(20);
   /*DATA DE VENCIMENTO DO BOLETO*/
   DECLARE @V_DTBOLETO DATETIME;
   /*CONTA CORRENTE DO FORNECEDOR (PREFERENCIAL)*/
   DECLARE @V_CDBANCFORN VARCHAR(3);
   DECLARE @V_CDAGENFORN VARCHAR(5);
   DECLARE @V_CDCCORFORN VARCHAR(10);
   /*IDENTIFICADOR DE BOLETO REAL*/
   DECLARE @V_IDBPAGREAL VARCHAR(1);
   /*IDDENTIFICADOR PARA CONSIDERAR AJUSTE DE BONIFICAO*/
   DECLARE @V_IDCONDESBONFORN VARCHAR(1);
   /*CHAVE DO BOLETO J EXISTENTE (PARA AGRUPAMENTO DE BOLETOS)*/
   DECLARE @V_CDFILIBOLFORN VARCHAR(4);
   DECLARE @V_NRLANBOLFORN VARCHAR(10);
   /*CHAVE DA AF*/
   DECLARE @V_CDFILLANC VARCHAR(4);
   DECLARE @V_CDFILDEST VARCHAR(4);
   DECLARE @V_NRAUTOFORN VARCHAR(10);
   DECLARE @V_NRLANCTONF VARCHAR(10);
   /*CHAVE DO PEDIDO*/
   DECLARE @V_CDFILPEDIDO VARCHAR(4);
   DECLARE @V_NRPEDIDO VARCHAR(10);
   /*DESCRIO DO TIPO DE CONTA*/
   DECLARE @V_DESCRICAO VARCHAR(2000);
   /*TIPO DE CONTA A PAGAR POR PRODUTO*/

   /*VARIVEIS PARA O CURSOR C_TP_CONTA_PRODPAG*/
   DECLARE @V_PROD_TPCTPAG VARCHAR(6);
   DECLARE @V_PROD_CDCLASSFIN VARCHAR(6);
   DECLARE @V_PROD_DSDEFACTPAG VARCHAR(40);
   DECLARE @V_PROD_VRBRUTITEM NUMERIC(15,2);

   /*VARIVEIS PARA O CURSOR C_TP_CONTA_PROD_REC*/
   DECLARE @V_PROD_CDTPCTRECEB VARCHAR(6);
   DECLARE @V_PROD_CDCLASSFINAREC VARCHAR(6);

   /*VARIVEIS PARA O CURSOR C_PARAM_EMPRESA*/
   DECLARE @V_EMPR_VRPEMOREMPR NUMERIC(15,2);
   DECLARE @V_EMPR_VRPEMULEMPR NUMERIC(15,2);
   DECLARE @V_EMPR_CDTPBAIXAPAG VARCHAR(2);
   DECLARE @V_EMPR_CDTPBAIXAREC VARCHAR(2);
   DECLARE @V_EMPR_CDREDUCONT VARCHAR(3);

   /*VARIVEIS PARA O CURSOR C_PARAM_FILIAL*/
   DECLARE @V_FIL_CDTPBAIXAPAG VARCHAR(2);
   DECLARE @V_FIL_CDTPBAIXAREC VARCHAR(2);
   DECLARE @V_FIL_CDREDUCONTPAG VARCHAR(3);
   DECLARE @V_FIL_IDCONDESBONFORN VARCHAR(1);

   /*VARIVEIS PARA O CURSOR C_FORNECEDOR*/
   DECLARE @V_FORN_CDFORNECED VARCHAR(21);
   DECLARE @V_FORN_IDAGRUBOLFOR VARCHAR(1);
   DECLARE @V_FORN_CDBANCFORN VARCHAR(3);
   DECLARE @V_FORN_CDAGENFORN VARCHAR(5);
   DECLARE @V_FORN_CDCCORFORN VARCHAR(10);
   DECLARE @V_FORN_IDCCORFORNPREF VARCHAR(1);
   DECLARE @V_FORN_CDTPBAIXAPAG VARCHAR(2);
   DECLARE @V_FORN_CDTPCTPAGAR  VARCHAR(6);

   /*VARIVEIS PARA O CURSOR C_CLIENTE*/
   DECLARE @V_CLI_VRPEMORBCLI NUMERIC(15,2);
   DECLARE @V_CLI_VRPEMULBCLI NUMERIC(15,2);

   /*VARIVEIS PARA O CURSOR C_TIPOOPER*/
   DECLARE @V_TPOP_CDTPCTPAGAR VARCHAR(6);
   DECLARE @V_TPOP_CDTPCTRECEB VARCHAR(6);
   DECLARE @V_TPOP_IDGERAVENC VARCHAR(1);
   DECLARE @V_TPOP_IDUTILVENC VARCHAR(1);
   DECLARE @V_TPOP_CDHISTPADR VARCHAR(4);

   /*VARVEIS DO CURSOR C_ITEMTRAB*/
   DECLARE @V_ITEM_DTVENCIMENTO DATETIME;
   DECLARE @V_ITEM_VRPAGO NUMERIC(15,2);
   DECLARE @V_ITEM_QTDIAS DOUBLE PRECISION;
   DECLARE @V_ITEM_NRSEQUENCIAL VARCHAR(5);
   DECLARE @V_ITEM_IDTPCONTATRABVEN VARCHAR(6);

   /*VARIVEIS PARA O CURSOR C_CONTAPAGAR*/
   DECLARE @V_CNT_CDFILIAL VARCHAR(4);
   DECLARE @V_CNT_NRLANCTONF VARCHAR(10);
   DECLARE @V_CNT_NRSEQVENPAG VARCHAR(2);
   DECLARE @V_CNT_NRPARCELAPAG VARCHAR(2);
   DECLARE @V_CNT_QTDIASVENPAG DOUBLE PRECISION;
   DECLARE @V_CNT_DTORIGVENPAG DATETIME;
   DECLARE @V_CNT_VRORIGPAG NUMERIC(15,2);
   DECLARE @V_CNT_CDTPCTPAGAR VARCHAR(6);
   DECLARE @V_CNT_DTATUAVENPAG DATETIME;
   DECLARE @V_CNT_VRATUAPAG NUMERIC(15,2);
   DECLARE @V_CNT_IDSTATPAG VARCHAR(1);
   DECLARE @V_CNT_NRLANBOLPAG VARCHAR(10);
   DECLARE @V_CNT_CDFILIBPAG VARCHAR(4);
   DECLARE @V_CNT_CDCLASSFINA VARCHAR(6);
   DECLARE @V_CNT_DTMOVFLUXO DATETIME;
   DECLARE @V_CNT_IDMOVFLUXO VARCHAR(1);
   DECLARE @V_CNT_CDFIMOVFLPAG VARCHAR(4);
   DECLARE @V_CNT_CDEMPRESA VARCHAR(2);
   DECLARE @V_CNT_DSCONTAPAG VARCHAR(200);
   DECLARE @V_CNT_VRATUAPAGTOT NUMERIC(15,2);
   DECLARE @V_CNT_VRTOTIMPONF NUMERIC(15,2);

   /*VARIVEIS PARA O CURSOR DE CONTAS A RECEBER*/
   DECLARE @V_CNT_NRSEQVENREC VARCHAR(2);
   DECLARE @V_CNT_NRPARCELAREC VARCHAR(2);
   DECLARE @V_CNT_VRATUAREC NUMERIC(15,2);
   DECLARE @V_CNT_CDTPCTRECEB VARCHAR(6);
   /*VARIVEIS PARA O CURSOR C_NOTAFISCAL*/
   DECLARE @V_NF_CDFILIAL VARCHAR(4);
   DECLARE @V_NF_NRLANCTONF VARCHAR(10);
   DECLARE @V_NF_NRNOTAFISC VARCHAR(20);
   DECLARE @V_NF_NRINSJURCLIE VARCHAR(20);
   DECLARE @V_NF_IDTPIJURCLIE VARCHAR(1);
   DECLARE @V_NF_NMFANTCLIE VARCHAR(50);
   DECLARE @V_NF_NMRAZSOCCLIE VARCHAR(50);
   DECLARE @V_NF_NRINSJURFORN VARCHAR(20);
   DECLARE @V_NF_IDTPIJURFORN VARCHAR(1);
   DECLARE @V_NF_NMFANTFORN VARCHAR(50);
   DECLARE @V_NF_NMRAZSOCFORN VARCHAR(50);
   DECLARE @V_NF_DTEMISSAO DATETIME;
   DECLARE @V_NF_DTENTRSAID DATETIME;
   DECLARE @V_NF_CDSERIEENTR VARCHAR(5);
   DECLARE @V_NF_CDAJUCTPAG VARCHAR(4);
   DECLARE @V_NF_IDTPIJURNF VARCHAR(1);
   DECLARE @V_NF_NRINSJURNF VARCHAR(20);
   DECLARE @V_NF_NRNOTAFISCRELAC VARCHAR(20);
   DECLARE @V_NF_DSPRODEMIS VARCHAR(400);

   /*VARIVES PARA CURSOR C_AJFORN*/
   DECLARE @V_AJFORN_CDAJUCTPAG VARCHAR(4);
   DECLARE @V_AJFORN_VRPEDESCFORN NUMERIC(15,2);
   DECLARE @V_AJFORN_IDTPDESCFORN VARCHAR(1);
   DECLARE @V_AJFORN_DTINIVRPDESC DATETIME;
   DECLARE @V_AJFORN_IDAJUCTPAG VARCHAR(1);

   /*VARIVEIS PARA A CONTA A RECEBER*/
   DECLARE @V_DSCONTAREC VARCHAR(200);
   /*DATA DE VENCIMENTO DA CONTA A RECEBER*/
   DECLARE @V_DTVENREC DATETIME;
   /*VALOR DA CONTA A RECEBER*/
   DECLARE @V_VRCONTREC NUMERIC(15,2);
   /*SEQUENCIAL DA CONTA A RECEBER*/
   DECLARE @V_NRSEQVENREC VARCHAR(2);
   /*TIPO DE CONTA RECEBER*/
   DECLARE @V_CDTPCTREC VARCHAR(6);
   /*TIPO DE CONTA PARAMETRIZADO PARA CONTA DE SUBST. TRIBUTARIA*/
   DECLARE @V_TPCTSUBTRIB VARCHAR(6);

   /*VARIVEIS PARA O CURSO C_ITEMNOTA*/
   DECLARE @V_ITEMNOTA_CDFILIALIT VARCHAR(4);
   DECLARE @V_ITEMNOTA_NRLANCTONFIT VARCHAR(10);

   /*Identificador de feriado bancrio  */
   DECLARE @V_IDCOFERIBANC  VARCHAR(1);

   /*FERIADOS BANCRIOS*/
   DECLARE @V_DTFERIBANC DATETIME;

   /*valor dos produtos da nota que n gera venvimento*/
   DEClARE @V_VRPRODUTOSEMFIN DOUBLE PRECISION;

BEGIN
   SET @P_RESULTADO = '';
   /*BUSCA INFORMAES DA NOTA FISCAL PARA GERAO DOS DADOS*/
   SELECT @V_CDEMPRESA = CDEMPRESA, @V_VRNOTAFISC = VRNOTAFISC, @V_ORIGDESTNF = ISNULL(IDORIGDESTNF,'C'),
          @V_ENTRSAIDOP = IDENTRSAIDOP, @V_CDFILIRECE = ISNULL(CDFILIRECE, CDFILIAL),
          @V_CDFILIEMIT = ISNULL(CDFILIEMIT, CDFILIAL), @V_CDFORNECED = CDFORNECED,
          @V_CDCLIENTE = CDCLIENTE, @V_DTEMISSAO = DTEMISSAO, @V_DTENTRSAID = DTENTRSAID,
          @V_IDDOCFINANC = IDDOCFINANC, @V_IDSISTEMA = IDSISTEMA, @V_CDINSESTA = CDINSCESTAST,
          @V_CDTIPOOPER = CDTIPOOPER, @V_IDSTATUS = IDSTATUS, @V_NRLANCCONT = NRLANCTBDOC
     FROM NOTAFISCAL
    WHERE CDFILIAL = @P_CDFILIAL
      AND NRLANCTONF = @P_NRLANCTONF;

   /*INFORMAES SOBRE O TIPO DE OPERAO*/
   SELECT @V_TPOP_CDTPCTPAGAR = CDTPCTPAGAR, @V_TPOP_CDTPCTRECEB = CDTPCTRECEB,
          @V_TPOP_IDGERAVENC = IDGERAVENC, @V_TPOP_IDUTILVENC = IDUTILVENC,
          @V_TPOP_CDHISTPADR = CDHISTPADR
     FROM TIPOOPERAC
    WHERE CDTIPOOPER = @V_CDTIPOOPER
      AND IDUTILOPER <> 'N'
      AND IDENTRSAIDOP = @V_ENTRSAIDOP;

   /* VERIFICA OS IMPOSTOS RETIDOS*/
   SELECT @V_VRIMPORETI = ISNULL(SUM(VRTOTIMPONF), 0)
   FROM IMPOSNFTOT INF, IMPOSTO I
   WHERE INF.CDFILIAL   = @P_CDFILIAL   AND
         INF.NRLANCTONF = @P_NRLANCTONF AND
         INF.CDIMPOSTO  = I.CDIMPOSTO   AND
         I.IDDESCRFONTE = 'R'           AND
         I.IDTRATIMPO   = 'R';

   IF (@V_VRIMPORETI IS NULL) BEGIN
      SET @V_VRIMPORETI = 0;
   END;


   SELECT @V_VRPRODUTOSEMFIN = SUM(IP.VRBRUTITEM)
     FROM ITEMPRODUTO IP, NOTAFISCAL NF, TPOPERCFOP T
    WHERE NF.CDFILIAL     = @P_CDFILIAL
      AND NF.NRLANCTONF   = @P_NRLANCTONF
      AND NF.CDFILIAL     = IP.CDFILIAL
      AND NF.NRLANCTONF   = IP.NRLANCTONF
      AND NF.IDENTRSAIDOP = T.IDENTRSAIDOP
      AND NF.CDTIPOOPER   = T.CDTIPOOPER
      AND IP.CDFISOPEITEM = T.CDFISCOPER
      AND T.IDCOMPOEVENC  = 'N';

   IF (@V_VRPRODUTOSEMFIN IS NULL) BEGIN
      SET @V_VRPRODUTOSEMFIN = 0;
   END;
      
   /*CONSIDERA IMPOSTOS RETIDOS PARA GERAO DAS CONTAS*/
   SET @V_VRNOTAFISC = ROUND(@V_VRNOTAFISC - @V_VRIMPORETI - @V_VRPRODUTOSEMFIN ,2, 0);

   IF (@V_ENTRSAIDOP = 'S') AND (@V_CDTIPOOPER = '05') BEGIN
      /*DETERMINA O VALOR REAL DA NOTA FISCAL CONSIDERANDO OS ENCARGOS*/
      SELECT @V_VRNOTAFISC = (A.VRLIQUIDO + B.VRSOMAENCA - C.VRMENOENCA)
        FROM (SELECT ISNULL(SUM(N.VRNOTAFISC),0) AS VRLIQUIDO
              FROM NOTAFISCAL N, ITEMNOTAFISC I
              WHERE I.CDFILIAL   = @P_CDFILIAL   AND
                    I.NRLANCTONF = @P_NRLANCTONF AND
                    N.CDFILIAL   = I.CDFILIALIT  AND
                    N.NRLANCTONF = I.NRLANCTONFIT) A,
             (SELECT ISNULL(SUM(VRITEMENCA),0) AS VRSOMAENCA
                FROM ITEMENCARGO, ENCARGO
               WHERE ITEMENCARGO.CDFILIAL   = @P_CDFILIAL AND
                     ITEMENCARGO.NRLANCTONF = @P_NRLANCTONF AND
                     ITEMENCARGO.CDENCARGO  = ENCARGO.CDENCARGO AND
                     IDENCARGO = 'A') B,
             (SELECT ISNULL(SUM(VRITEMENCA),0) AS VRMENOENCA
                FROM ITEMENCARGO, ENCARGO
               WHERE ITEMENCARGO.CDFILIAL   = @P_CDFILIAL AND
                     ITEMENCARGO.NRLANCTONF = @P_NRLANCTONF AND
                     ITEMENCARGO.CDENCARGO  = ENCARGO.CDENCARGO AND
                     IDENCARGO = 'D') C;
   END;

   SET @V_CDFILLANC = NULL;
   SET @V_CDFILDEST = NULL;
   SET @V_NRAUTOFORN = NULL;
   SET @V_CDFILPEDIDO = NULL;
   SET @V_NRPEDIDO = NULL;
   /*PARA GERAO DE VENCIMENTOS AUTOMATICAMENTE O VALOR NO PODE SER ZERO E O TIPO DE OPERAO
   DEVE ESTAR DEVIDAMENTE PARAMETRIZADO. NO H GERAO DE CONTAS PARA NOTAS FISCAIS ORIGINADAS
   DOS SISTEMAS FINANCEIROS*/
   IF (@V_VRNOTAFISC > 0) AND
      (@V_IDDOCFINANC <> 'L') BEGIN
      IF @V_ENTRSAIDOP = 'E' BEGIN
         SET @V_CLIEFORN = @V_CDFORNECED;
         SET @V_CDFILIEMIRECE = @V_CDFILIRECE;
         /*VERIFICA SE A NOTA FISCAL  RELACIONADA  UMA AF*/
         SELECT @V_CDFILLANC = MAX(CDFILLANC), @V_CDFILDEST = MAX(CDFILDEST), @V_NRAUTOFORN = MAX(NRAUTOFORN)
           FROM
              NFRELACAF
           WHERE
              (CDFILIAL = @P_CDFILIAL) AND
              (NRLANCTONF = @P_NRLANCTONF);

         /*DETERMINA SE A GERAO DE VENCIMENTOS SER FEITA CONFORME
         A FORMA DE PAGAMENTO DA AF */
         IF NOT (@V_NRAUTOFORN IS NULL) BEGIN
            SET @V_ENTRSAIDOP = 'A';
         END;
         /*OPERAO DE LANAMENTO DE NOTA FISCAL*/
         IF @P_IDOPERACAO = 'L' BEGIN
            IF (@V_TPOP_IDUTILVENC <> 'N') OR
               (@V_TPOP_IDGERAVENC <> 'N') BEGIN

               /*CRIA OS VENCIMENTOS SEGUNDO A FORMA DE PAGAMENTO*/
               EXEC CRIA_VENCIMENTO @P_CDFILIAL,
                                    @P_NRLANCTONF,
                                    @V_ENTRSAIDOP,
                                    @V_VRNOTAFISC,
                                    @V_DTEMISSAO,
                                    @V_DTENTRSAID,
                                    @V_CLIEFORN,
                                    @V_CDFILIEMIRECE,
                                    @V_ORIGDESTNF,
                                    @V_CDFILLANC,
                                    @V_CDFILDEST,
                                    @V_NRAUTOFORN,
                                    @V_CDFILPEDIDO,
                                    @V_NRPEDIDO;

               DECLARE C_ITEMTRAB CURSOR FOR
                  SELECT DTVENCIMENTO, VRVENCIMENTO, QTDIASVENC, NRSEQVENC
                    FROM TRAB_VENCIMENTO
                   WHERE CDFILIALVENC = @P_CDFILIAL
                     AND NRLANCTONFVENC = @P_NRLANCTONF
                   ORDER BY NRSEQVENC;
               OPEN C_ITEMTRAB;
               FETCH NEXT FROM C_ITEMTRAB INTO
               @V_ITEM_DTVENCIMENTO,
               @V_ITEM_VRPAGO,
               @V_ITEM_QTDIAS,
               @V_ITEM_NRSEQUENCIAL;
               /*INSERE A CONTA A PAGAR DE ACORDO COM OS VENCIMENTOS GERADOS*/
               /*TRAB_VENCIMENTO : TABELA TEMPORRIA PREENCHIDA PELA CRIA_VENCIMENTO*/
               WHILE (@@FETCH_STATUS = 0) BEGIN
                  /*INSERE OS VENCIMENTOS GERADOS NA TABELA DE CONTAS A PAGAR*/
                  INSERT INTO CONTAPAGAR
                     (CDFILIAL, NRLANCTONF, CDMOTIPROR, CDMOTIPARC, CDTPCTPAGAR, NRSEQVENPAG,
                     NRPARCELAPAG, QTDIASVENPAG, DTORIGVENPAG, VRORIGPAG, DTATUAVENPAG, VRATUAPAG,
                     IDSTATPAG, DSCONTAPAG, CDFILIBPAG, NRLANBOLPAG)
                  VALUES
                     (@P_CDFILIAL, @P_NRLANCTONF, NULL, NULL, NULL, SUBSTRING(@V_ITEM_NRSEQUENCIAL, LEN(@V_ITEM_NRSEQUENCIAL) -1,2), '00', @V_ITEM_QTDIAS,
                      @V_ITEM_DTVENCIMENTO, @V_ITEM_VRPAGO, @V_ITEM_DTVENCIMENTO , @V_ITEM_VRPAGO, 'A', NULL, NULL, NULL);

                  FETCH NEXT FROM C_ITEMTRAB INTO
                  @V_ITEM_DTVENCIMENTO,
                  @V_ITEM_VRPAGO,
                  @V_ITEM_QTDIAS,
                  @V_ITEM_NRSEQUENCIAL;
               END;
               CLOSE C_ITEMTRAB;
               DEALLOCATE C_ITEMTRAB;
            END;
         END
         ELSE BEGIN
            /*OPERAO DE TRANSFERNCIA DE NOTA FISCAL ELETRNICA*/
            IF @P_IDOPERACAO = 'T' BEGIN
               /*VERIFICA SE AS CONTAS DO DOCUMENTO NO POSSUEM TIPO DE CONTA INFORMADO*/
               SELECT @V_COUNT = COUNT(*)
                 FROM CONTAPAGAR
                WHERE CDFILIAL = @P_CDFILIAL
                  AND NRLANCTONF = @P_NRLANCTONF
                  AND CDTPCTPAGAR IS NOT NULL;
               /*SE AS CONTAS EXISTENTES NO POSSUREM TIPO DE CONTA*/
               IF (@V_COUNT = 0) BEGIN

                  /*VERIFICA SE A NOTA VEM DE UMA AF QUE POSSUI TIPO DE CONTA A PAGAR PARAMETRIZADO*/
                  SELECT @V_TPCONTAPAG_AF = MAX(T.CDTPCTPAGAR)
                    FROM TIPOCTPAGAR T, AUTOFORNE A, NFRELACAF N
                   WHERE N.CDFILIAL    = @P_CDFILIAL   AND
                         N.NRLANCTONF  = @P_NRLANCTONF AND
                         A.CDFILDEST   = N.CDFILDEST   AND
                         A.CDFILLANC   = N.CDFILLANC   AND
                         A.NRAUTOFORN  = N.NRAUTOFORN  AND
                         A.CDTPCTPAGAR = T.CDTPCTPAGAR;

                   /* Verifica se a nota esta ligada com mais de 1 af com tipo de conta diferentes */
                   SELECT @V_COUNTTPCONTA_AF = COUNT(DISTINCT T.CDTPCTPAGAR)
                    FROM TIPOCTPAGAR T, AUTOFORNE A, NFRELACAF N
                   WHERE N.CDFILIAL    = @P_CDFILIAL   AND
                         N.NRLANCTONF  = @P_NRLANCTONF AND
                         A.CDFILDEST   = N.CDFILDEST   AND
                         A.CDFILLANC   = N.CDFILLANC   AND
                         A.NRAUTOFORN  = N.NRAUTOFORN  AND
                         A.CDTPCTPAGAR = T.CDTPCTPAGAR;

                  SELECT @V_COUNT = COUNT(*)
                    FROM CONTAPAGAR
                   WHERE CDFILIAL = @P_CDFILIAL
                     AND NRLANCTONF = @P_NRLANCTONF;
                  /*SE O DOCUMENTO NO POSSUI CONTA A PAGAR*/
                  IF (@V_COUNT = 0) BEGIN
                     /*CRIA OS VENCIMENTOS DE ACORDO COM A FORMA DE PAGAMENTO*/
                     EXEC CRIA_VENCIMENTO @P_CDFILIAL,
                                          @P_NRLANCTONF,
                                          @V_ENTRSAIDOP,
                                          @V_VRNOTAFISC,
                                          @V_DTEMISSAO,
                                          @V_DTENTRSAID,
                                          @V_CLIEFORN,
                                          @V_CDFILIEMIRECE,
                                          @V_ORIGDESTNF,
                                          @V_CDFILLANC,
                                          @V_CDFILDEST,
                                          @V_NRAUTOFORN,
                                          @V_CDFILPEDIDO,
                                          @V_NRPEDIDO;
                     SET @V_SEQUENCIAL = 1;
                     /*APAGA AS CONTAS A PAGAR RELACIONADAS  NOTAFISCAL*/
                     DELETE FROM CONTAPAGAR
                     WHERE CDFILIAL = @P_CDFILIAL
                       AND NRLANCTONF = @P_NRLANCTONF;

                     DECLARE C_ITEMTRAB CURSOR FOR
                        SELECT DTVENCIMENTO, VRVENCIMENTO, QTDIASVENC, NRSEQVENC
                          FROM TRAB_VENCIMENTO
                         WHERE CDFILIALVENC = @P_CDFILIAL
                           AND NRLANCTONFVENC = @P_NRLANCTONF
                         ORDER BY NRSEQVENC;
                     OPEN C_ITEMTRAB;
                     FETCH NEXT FROM C_ITEMTRAB INTO
                     @V_ITEM_DTVENCIMENTO,
                     @V_ITEM_VRPAGO,
                     @V_ITEM_QTDIAS,
                     @V_ITEM_NRSEQUENCIAL;
                     /*PESQUISA OS VENCIMENTOS GERADOS*/
                     WHILE (@@FETCH_STATUS = 0) BEGIN
                        SET @V_VRVENCACUM = 0;
                        SET @V_COUNT = 1;

                        /*SE NO TIVER TIPO DE CONTA PARAMETRIZADA NA AF*/
                        IF (@V_TPCONTAPAG_AF IS NULL OR
                            @V_COUNTTPCONTA_AF > 1)  BEGIN
                           /*BUSCA PARAMETRIZAO DE TIPO DE CONTA POR PRODUTO DA NOTA*/
                           DECLARE C_TP_CONTA_PROD_PAG CURSOR FOR
                              SELECT PROD.CDTPCTPAGAR, TP.CDCLASSFINA, TP.DSDEFACTPAG, SUM(PROD.VRBRUTITEM) AS VRBRUTITEM
                                FROM TIPOCTPAGAR TP,
                                     (SELECT P3.CDPRODUTO, P4.CDARVPROD, P4.CDTPCTPAGAR,
                                            ROUND(I.VRBRUTITEM,2) AS VRBRUTITEM
                                       FROM ITEMPRODUTO I, PRODUTO P3, PRODUTO P4
                                      WHERE I.CDFILIAL = @P_CDFILIAL
                                        AND I.NRLANCTONF = @P_NRLANCTONF
                                        AND I.CDPRODUTO = P3.CDPRODUTO
                                        AND (CHARINDEX(ISNULL(RTRIM(P4.CDARVPROD),P3.CDARVPROD), P3.CDARVPROD) = 1)
                                        AND P4.CDTPCTPAGAR IS NOT NULL
                                        AND P4.CDARVPROD = (SELECT MAX(P1.CDARVPROD)
                                                              FROM ITEMPRODUTO IT,  PRODUTO P, PRODUTO P1
                                                             WHERE IT.CDFILIAL = I.CDFILIAL
                                                               AND IT.NRLANCTONF = I.NRLANCTONF
                                                               AND IT.CDPRODUTO = I.CDPRODUTO
                                                               AND IT.CDPRODUTO = P.CDPRODUTO
                                                               AND (CHARINDEX(ISNULL(RTRIM(P1.CDARVPROD),P.CDARVPROD), P.CDARVPROD) = 1)
                                                               AND P1.CDTPCTPAGAR IS NOT NULL)
                                        AND NOT EXISTS (SELECT 1
                                                          FROM NOTAFISCAL NF, TPOPERCFOP T
                                                         WHERE NF.CDFILIAL     = @P_CDFILIAL
                                                           AND NF.NRLANCTONF   = @P_NRLANCTONF
                                                           AND NF.CDFILIAL     = I.CDFILIAL
                                                           AND NF.NRLANCTONF   = I.NRLANCTONF
                                                           AND I.CDFISOPEITEM  = T.CDFISCOPER
                                                           AND NF.IDENTRSAIDOP = T.IDENTRSAIDOP
                                                           AND NF.CDTIPOOPER   = T.CDTIPOOPER
                                                           AND T.IDCOMPOEVENC  = 'N')
                                 ) PROD
                                WHERE PROD.CDTPCTPAGAR = TP.CDTPCTPAGAR
                                GROUP BY PROD.CDTPCTPAGAR, TP.CDCLASSFINA, TP.DSDEFACTPAG;
                           OPEN C_TP_CONTA_PROD_PAG;
                           FETCH NEXT FROM C_TP_CONTA_PROD_PAG INTO
                           @V_PROD_TPCTPAG,
                           @V_PROD_CDCLASSFIN,
                           @V_PROD_DSDEFACTPAG,
                           @V_PROD_VRBRUTITEM;

                           SELECT @V_ROW_COUNT = COUNT(*)
                             FROM (SELECT ISNULL(P.CDTPCTPAGAR, X.CDTPCTPAGAR) CDTPCTPAGAR , TP.CDCLASSFINA, TP.DSDEFACTPAG, SUM(I.VRBRUTITEM) AS VRBRUTITEM
                                     FROM PRODUTO P,
                                          ITEMPRODUTO I LEFT JOIN (SELECT P.CDARVPROD, P.CDPRODUTO, P1.CDTPCTPAGAR
                                                                     FROM ITEMPRODUTO I, PRODUTO P, PRODUTO P1
                                                                    WHERE I.CDFILIAL = @P_CDFILIAL
                                                                      AND I.NRLANCTONF = @P_NRLANCTONF
                                                                      AND I.CDPRODUTO = P.CDPRODUTO
                                                                      AND P1.CDARVPROD = (SELECT MAX(E.CDARVPROD)
                                                                                            FROM PRODUTO E
                                                                                            WHERE CDTPCTPAGAR IS NOT NULL
                                                                                              AND (CHARINDEX(E.CDARVPROD, P.CDARVPROD) = 1))) X
                                                                  ON I.CDPRODUTO = X.CDPRODUTO
                                                           LEFT JOIN TIPOCTPAGAR TP
                                                                  ON X.CDTPCTPAGAR = TP.CDTPCTPAGAR

                                    WHERE I.CDFILIAL = @P_CDFILIAL
                                      AND I.NRLANCTONF = @P_NRLANCTONF
                                      AND I.CDPRODUTO = P.CDPRODUTO
                                   GROUP BY ISNULL(P.CDTPCTPAGAR, X.CDTPCTPAGAR), TP.CDCLASSFINA, TP.DSDEFACTPAG
                                   ) A;

                           WHILE (@@FETCH_STATUS = 0) BEGIN
                               /*CLCULO DO VALOR DO VENCIMENTO PARA O TIPO DE CONTA, PROPORCIONALMENTE AO VENCIMENTO J GERADO E AO VALOR BRUTO DO ITEM*/
                               SET @V_VRVENCIMENTO = ROUND(@V_PROD_VRBRUTITEM * (@V_ITEM_VRPAGO/@V_VRNOTAFISC), 2);
                               /*CLCULO DO VALOR PROPORCIONAL DO IMPOSTO PARA O VALOR DE VENCIMENTO INFORMADO*/
                               SET @V_VRIMPOSTO = ROUND(@V_VRIMPORETI * (@V_VRVENCIMENTO/(@V_VRNOTAFISC + @V_VRIMPORETI)), 2);
                               /*VALOR DO VENCIMENTO J CONSIDERANDO O VALOR DO IMPOSTO*/
                               SET @V_VRVENCIMENTO = @V_VRVENCIMENTO - @V_VRIMPOSTO;
                               /*VALOR ACUMULATIVO DO VENCIMENTO*/
                               SET @V_VRVENCACUM = @V_VRVENCACUM + @V_VRVENCIMENTO;
                               /*VERIFICA SE AINDA EXISTE VALOR DO VENCIMENTO ORIGINAL A SER INSERIDO*/
                               IF (@V_COUNT = @V_ROW_COUNT) BEGIN
                                  SET @V_VRVENCIMENTO = @V_VRVENCIMENTO + ROUND(@V_ITEM_VRPAGO - @V_VRVENCACUM, 2);
                               END;
                               /*INCLUI AS CONTA A PAGAR*/
                               INSERT INTO CONTAPAGAR
                                  (CDFILIAL, NRLANCTONF, CDMOTIPROR, CDMOTIPARC, CDTPCTPAGAR, NRSEQVENPAG,
                                   NRPARCELAPAG, QTDIASVENPAG, DTORIGVENPAG, VRORIGPAG, DTATUAVENPAG, VRATUAPAG,
                                   IDSTATPAG, DSCONTAPAG, CDFILIBPAG, NRLANBOLPAG)
                               VALUES
                                  (@P_CDFILIAL, @P_NRLANCTONF, NULL, NULL, @V_PROD_TPCTPAG, RIGHT(REPLICATE('0',2) + CONVERT(VARCHAR, @V_SEQUENCIAL),2),  '00', @V_ITEM_QTDIAS,
                                   @V_ITEM_DTVENCIMENTO, @V_VRVENCIMENTO, @V_ITEM_DTVENCIMENTO , @V_VRVENCIMENTO, 'A', NULL, NULL, NULL);

                               SET @V_COUNT = @V_COUNT + 1;
                               SET @V_SEQUENCIAL = @V_SEQUENCIAL + 1;
                               FETCH NEXT FROM C_TP_CONTA_PROD_PAG INTO
                               @V_PROD_TPCTPAG,
                               @V_PROD_CDCLASSFIN,
                               @V_PROD_DSDEFACTPAG,
                               @V_PROD_VRBRUTITEM;
                           END;
                           CLOSE C_TP_CONTA_PROD_PAG;
                           DEALLOCATE C_TP_CONTA_PROD_PAG;
                        END;

                        IF (@V_COUNT = 1) BEGIN
                           /*INCLUI AS CONTA A PAGAR*/
                           INSERT INTO CONTAPAGAR
                              (CDFILIAL, NRLANCTONF, CDMOTIPROR, CDMOTIPARC, CDTPCTPAGAR, NRSEQVENPAG,
                               NRPARCELAPAG, QTDIASVENPAG, DTORIGVENPAG, VRORIGPAG, DTATUAVENPAG, VRATUAPAG,
                               IDSTATPAG, DSCONTAPAG, CDFILIBPAG, NRLANBOLPAG)
                           VALUES
                              (@P_CDFILIAL, @P_NRLANCTONF, NULL, NULL, @V_TPCONTAPAG_AF, SUBSTRING(@V_ITEM_NRSEQUENCIAL, LEN(@V_ITEM_NRSEQUENCIAL)-1, 2),  '00', @V_ITEM_QTDIAS,
                               @V_ITEM_DTVENCIMENTO, @V_ITEM_VRPAGO, @V_ITEM_DTVENCIMENTO , @V_ITEM_VRPAGO, 'A', NULL, NULL, NULL);
                        END;
                        FETCH NEXT FROM C_ITEMTRAB INTO
                        @V_ITEM_DTVENCIMENTO,
                        @V_ITEM_VRPAGO,
                        @V_ITEM_QTDIAS,
                        @V_ITEM_NRSEQUENCIAL;
                     END;
                     CLOSE C_ITEMTRAB;
                     DEALLOCATE C_ITEMTRAB;
                  END
                  /*SE O DOCUMENTO POSSUI CONTAS A PAGAR*/
                  ELSE BEGIN
                     SET @V_SEQUENCIAL = 1;

                     DECLARE C_VENCIMENTOS CURSOR FOR
                     SELECT CDFILIAL, NRLANCTONF, NRPARCELAPAG,
                            QTDIASVENPAG, DTORIGVENPAG, SUM(VRORIGPAG) AS VRORIGPAG,
                            DSCONTAPAG, DTATUAVENPAG, SUM(VRATUAPAG) AS VRATUAPAG,
                            IDSTATPAG, CDCLASSFINA, CT.VRATUAPAGTOT,
                            IMPRET.VRTOTIMPONF
                       FROM CONTAPAGAR IT,
                            (SELECT SUM(VRATUAPAG) AS VRATUAPAGTOT
                               FROM CONTAPAGAR
                              WHERE CDFILIAL = @P_CDFILIAL
                                AND NRLANCTONF = @P_NRLANCTONF) CT,
                            (SELECT SUM(A.VRTOTIMPONF) AS VRTOTIMPONF
                               FROM IMPOSNFTOT A, IMPOSTO B
                              WHERE A.CDFILIAL   = @P_CDFILIAL
                                AND A.NRLANCTONF = @P_NRLANCTONF
                                AND B.IDTRATIMPO = 'R'
                                AND B.IDDESCRFONTE = 'R'
                                AND A.CDIMPOSTO  = B.CDIMPOSTO) IMPRET
                      WHERE IT.CDFILIAL = @P_CDFILIAL
                        AND IT.NRLANCTONF = @P_NRLANCTONF
                      GROUP BY CDFILIAL, NRLANCTONF, NRPARCELAPAG,
                               QTDIASVENPAG, DTORIGVENPAG, DSCONTAPAG,
                               DTATUAVENPAG, IDSTATPAG, CDCLASSFINA,
                               CT.VRATUAPAGTOT, IMPRET.VRTOTIMPONF
                      ORDER BY DTORIGVENPAG;
                     OPEN C_VENCIMENTOS;
                     FETCH NEXT FROM C_VENCIMENTOS INTO
                     @V_CNT_CDFILIAL,
                     @V_CNT_NRLANCTONF,
                     @V_CNT_NRPARCELAPAG,
                     @V_CNT_QTDIASVENPAG,
                     @V_CNT_DTORIGVENPAG,
                     @V_CNT_VRORIGPAG,
                     @V_CNT_DSCONTAPAG,
                     @V_CNT_DTATUAVENPAG,
                     @V_CNT_VRATUAPAG,
                     @V_CNT_IDSTATPAG,
                     @V_CNT_CDCLASSFINA,
                     @V_CNT_VRATUAPAGTOT,
                     @V_CNT_VRTOTIMPONF;

                     /*APAGA AS CONTAS A PAGAR RELACIONADAS  NOTAFISCAL*/
                     DELETE FROM CONTAPAGAR
                     WHERE CDFILIAL = @P_CDFILIAL
                       AND NRLANCTONF = @P_NRLANCTONF;

                     WHILE (@@FETCH_STATUS = 0) BEGIN
                        SET @V_VRVENCACUM = 0;
                        SET @V_COUNT = 1;

                        IF (@V_TPCONTAPAG_AF IS NULL OR
                            @V_COUNTTPCONTA_AF > 1) BEGIN
                           /*BUSCA PARAMETRIZAO DE TIPO DE CONTA POR PRODUTO DA NOTA*/
                           DECLARE C_TP_CONTA_PROD_PAG CURSOR FOR
                              SELECT ISNULL(P.CDTPCTPAGAR, X.CDTPCTPAGAR) CDTPCTPAGAR , TP.CDCLASSFINA, TP.DSDEFACTPAG, SUM(I.VRBRUTITEM) AS VRBRUTITEM
                                FROM PRODUTO P,
                                     ITEMPRODUTO I LEFT JOIN (SELECT P.CDARVPROD, P.CDPRODUTO, P1.CDTPCTPAGAR
                                                                FROM ITEMPRODUTO I, PRODUTO P, PRODUTO P1
                                                               WHERE I.CDFILIAL = @P_CDFILIAL
                                                                 AND I.NRLANCTONF = @P_NRLANCTONF
                                                                 AND I.CDPRODUTO = P.CDPRODUTO
                                                                 AND P1.CDARVPROD = (SELECT MAX(E.CDARVPROD)
                                                                                       FROM PRODUTO E
                                                                                       WHERE CDTPCTPAGAR IS NOT NULL
                                                                                         AND (CHARINDEX(E.CDARVPROD, P.CDARVPROD) = 1))) X
                                                             ON I.CDPRODUTO = X.CDPRODUTO
                                                      LEFT JOIN TIPOCTPAGAR TP
                                                             ON X.CDTPCTPAGAR = TP.CDTPCTPAGAR

                               WHERE I.CDFILIAL = @P_CDFILIAL
                                 AND I.NRLANCTONF = @P_NRLANCTONF
                                 AND I.CDPRODUTO = P.CDPRODUTO
                              GROUP BY ISNULL(P.CDTPCTPAGAR, X.CDTPCTPAGAR), TP.CDCLASSFINA, TP.DSDEFACTPAG;

                           OPEN C_TP_CONTA_PROD_PAG;
                           FETCH NEXT FROM C_TP_CONTA_PROD_PAG INTO
                           @V_PROD_TPCTPAG,
                           @V_PROD_CDCLASSFIN,
                           @V_PROD_DSDEFACTPAG,
                           @V_PROD_VRBRUTITEM;

                           SELECT @V_ROW_COUNT = COUNT(*)
                             FROM (SELECT ISNULL(P.CDTPCTPAGAR, X.CDTPCTPAGAR) CDTPCTPAGAR , TP.CDCLASSFINA, TP.DSDEFACTPAG, SUM(I.VRBRUTITEM) AS VRBRUTITEM
                                     FROM PRODUTO P,
                                          ITEMPRODUTO I LEFT JOIN (SELECT P.CDARVPROD, P.CDPRODUTO, P1.CDTPCTPAGAR
                                                                     FROM ITEMPRODUTO I, PRODUTO P, PRODUTO P1
                                                                    WHERE I.CDFILIAL = @P_CDFILIAL
                                                                      AND I.NRLANCTONF = @P_NRLANCTONF
                                                                      AND I.CDPRODUTO = P.CDPRODUTO
                                                                      AND P1.CDARVPROD = (SELECT MAX(E.CDARVPROD)
                                                                                            FROM PRODUTO E
                                                                                            WHERE CDTPCTPAGAR IS NOT NULL
                                                                                              AND (CHARINDEX(E.CDARVPROD, P.CDARVPROD) = 1))) X
                                                                  ON I.CDPRODUTO = X.CDPRODUTO
                                                           LEFT JOIN TIPOCTPAGAR TP
                                                                  ON X.CDTPCTPAGAR = TP.CDTPCTPAGAR

                                    WHERE I.CDFILIAL = @P_CDFILIAL
                                      AND I.NRLANCTONF = @P_NRLANCTONF
                                      AND I.CDPRODUTO = P.CDPRODUTO
                                   GROUP BY ISNULL(P.CDTPCTPAGAR, X.CDTPCTPAGAR), TP.CDCLASSFINA, TP.DSDEFACTPAG
                                   ) A;

                           WHILE (@@FETCH_STATUS = 0) BEGIN
                               /*CLCULO DO VALOR DO VENCIMENTO PARA O TIPO DE CONTA, PROPORCIONALMENTE AO VENCIMENTO J GERADO E AO VALOR BRUTO DO ITEM*/
                               SET @V_VRVENCIMENTO = ROUND(@V_PROD_VRBRUTITEM * (@V_CNT_VRATUAPAG/@V_VRNOTAFISC), 2);
                               /*CLCULO DO VALOR PROPORCIONAL DO IMPOSTO PARA O VALOR DE VENCIMENTO INFORMADO*/
                               SET @V_VRIMPOSTO = ROUND(@V_VRIMPORETI * (@V_VRVENCIMENTO/(@V_VRNOTAFISC + @V_VRIMPORETI)), 2);
                               /*VALOR DO VENCIMENTO J CONSIDERANDO O VALOR DO IMPOSTO*/
                               SET @V_VRVENCIMENTO = @V_VRVENCIMENTO - @V_VRIMPOSTO;
                               /*VALOR ACUMULATIVO DO VENCIMENTO*/
                               SET @V_VRVENCACUM = @V_VRVENCACUM + @V_VRVENCIMENTO;
                               /*VERIFICA SE AINDA EXISTE VALOR DO VENCIMENTO ORIGINAL A SER INSERIDO*/
                               IF (@V_COUNT = @V_ROW_COUNT) BEGIN
                                  SET @V_VRVENCIMENTO = @V_VRVENCIMENTO + ROUND(@V_CNT_VRATUAPAG - @V_VRVENCACUM, 2);
                               END;
                               /*INCLUI AS CONTA A PAGAR*/
                               INSERT INTO CONTAPAGAR
                                  (CDFILIAL, NRLANCTONF, CDMOTIPROR, CDMOTIPARC, CDTPCTPAGAR, NRSEQVENPAG,
                                   NRPARCELAPAG, QTDIASVENPAG, DTORIGVENPAG, VRORIGPAG, DTATUAVENPAG, VRATUAPAG,
                                   IDSTATPAG, DSCONTAPAG, CDFILIBPAG, NRLANBOLPAG)
                               VALUES
                                  (@P_CDFILIAL, @P_NRLANCTONF, NULL, NULL, @V_PROD_TPCTPAG, RIGHT(REPLICATE('0',2) + CONVERT(VARCHAR, @V_SEQUENCIAL),2),  '00', @V_CNT_QTDIASVENPAG,
                                   @V_CNT_DTATUAVENPAG, @V_VRVENCIMENTO, @V_CNT_DTATUAVENPAG , @V_VRVENCIMENTO, 'A', @V_CNT_DSCONTAPAG, NULL, NULL);

                               SET @V_COUNT = @V_COUNT + 1;
                               SET @V_SEQUENCIAL = @V_SEQUENCIAL + 1;
                               FETCH NEXT FROM C_TP_CONTA_PROD_PAG INTO
                               @V_PROD_TPCTPAG,
                               @V_PROD_CDCLASSFIN,
                               @V_PROD_DSDEFACTPAG,
                               @V_PROD_VRBRUTITEM;
                           END;
                           CLOSE C_TP_CONTA_PROD_PAG;
                           DEALLOCATE C_TP_CONTA_PROD_PAG;
                        END;

                        IF (@V_COUNT = 1) BEGIN
                           /*INCLUI AS CONTA A PAGAR*/
                           INSERT INTO CONTAPAGAR
                              (CDFILIAL, NRLANCTONF, CDMOTIPROR, CDMOTIPARC, CDTPCTPAGAR, NRSEQVENPAG,
                               NRPARCELAPAG, QTDIASVENPAG, DTORIGVENPAG, VRORIGPAG, DTATUAVENPAG, VRATUAPAG,
                               IDSTATPAG, DSCONTAPAG, CDFILIBPAG, NRLANBOLPAG)
                           VALUES
                              (@P_CDFILIAL, @P_NRLANCTONF, NULL, NULL, @V_TPCONTAPAG_AF, RIGHT(REPLICATE('0',2) + CONVERT(VARCHAR, @V_SEQUENCIAL),2),  '00', @V_CNT_QTDIASVENPAG,
                               @V_CNT_DTATUAVENPAG, @V_CNT_VRATUAPAG, @V_CNT_DTATUAVENPAG, @V_CNT_VRATUAPAG, 'A', @V_CNT_DSCONTAPAG, NULL, NULL);
                           SET @V_SEQUENCIAL = @V_SEQUENCIAL + 1;
                        END;

                        FETCH NEXT FROM C_VENCIMENTOS INTO
                        @V_CNT_CDFILIAL,
                        @V_CNT_NRLANCTONF,
                        @V_CNT_NRPARCELAPAG,
                        @V_CNT_QTDIASVENPAG,
                        @V_CNT_DTORIGVENPAG,
                        @V_CNT_VRORIGPAG,
                        @V_CNT_DSCONTAPAG,
                        @V_CNT_DTATUAVENPAG,
                        @V_CNT_VRATUAPAG,
                        @V_CNT_IDSTATPAG,
                        @V_CNT_CDCLASSFINA,
                        @V_CNT_VRATUAPAGTOT,
                        @V_CNT_VRTOTIMPONF;
                     END;
                     CLOSE C_VENCIMENTOS;
                     DEALLOCATE C_VENCIMENTOS;
                  END;
               END;
            END
            ELSE BEGIN
               /*OPERAO DE APROVAO DE NOTA FISCAL*/
               IF @P_IDOPERACAO = 'A' BEGIN
                  /*VERIFICA SE AS CONTAS DO DOCUMENTO NO POSSUEM TIPO DE CONTA INFORMADO*/
                  SELECT @V_COUNT = COUNT(*)
                    FROM CONTAPAGAR
                   WHERE CDFILIAL = @P_CDFILIAL
                     AND NRLANCTONF = @P_NRLANCTONF
                     AND CDTPCTPAGAR IS NOT NULL;
                  /*SE AS CONTAS EXISTENTES NO POSSUREM TIPO DE CONTA*/
                  IF (@V_COUNT = 0) BEGIN

                     /*VERIFICA SE A NOTA VEM DE UMA AF QUE POSSUI TIPO DE CONTA A PAGAR PARAMETRIZADO*/
                     SELECT @V_TPCONTAPAG_AF = MAX(T.CDTPCTPAGAR)
                       FROM TIPOCTPAGAR T, AUTOFORNE A, NFRELACAF N
                      WHERE N.CDFILIAL    = @P_CDFILIAL   AND
                            N.NRLANCTONF  = @P_NRLANCTONF AND
                            A.CDFILDEST   = N.CDFILDEST   AND
                            A.CDFILLANC   = N.CDFILLANC   AND
                            A.NRAUTOFORN  = N.NRAUTOFORN  AND
                            A.CDTPCTPAGAR = T.CDTPCTPAGAR;

                      /* Verifica se a nota esta ligada com mais de 1 af com tipo de conta diferentes */
                     SELECT @V_COUNTTPCONTA_AF = COUNT(DISTINCT T.CDTPCTPAGAR)
                       FROM TIPOCTPAGAR T, AUTOFORNE A, NFRELACAF N
                      WHERE N.CDFILIAL    = @P_CDFILIAL   AND
                            N.NRLANCTONF  = @P_NRLANCTONF AND
                            A.CDFILDEST   = N.CDFILDEST   AND
                            A.CDFILLANC   = N.CDFILLANC   AND
                            A.NRAUTOFORN  = N.NRAUTOFORN  AND
                            A.CDTPCTPAGAR = T.CDTPCTPAGAR;

                     SELECT @V_COUNT = COUNT(*)
                       FROM CONTAPAGAR
                      WHERE CDFILIAL = @P_CDFILIAL
                        AND NRLANCTONF = @P_NRLANCTONF;
                     /*SE O DOCUMENTO NO POSSUI CONTA A PAGAR*/
                     IF (@V_COUNT = 0) BEGIN
                        /*CRIA OS VENCIMENTOS DE ACORDO COM A FORMA DE PAGAMENTO*/
                        EXEC CRIA_VENCIMENTO @P_CDFILIAL,
                                             @P_NRLANCTONF,
                                             @V_ENTRSAIDOP,
                                             @V_VRNOTAFISC,
                                             @V_DTEMISSAO,
                                             @V_DTENTRSAID,
                                             @V_CLIEFORN,
                                             @V_CDFILIEMIRECE,
                                             @V_ORIGDESTNF,
                                             @V_CDFILLANC,
                                             @V_CDFILDEST,
                                             @V_NRAUTOFORN,
                                             @V_CDFILPEDIDO,
                                             @V_NRPEDIDO;
                        SET @V_SEQUENCIAL = 1;
                        /*APAGA AS CONTAS A PAGAR RELACIONADAS  NOTAFISCAL*/
                        DELETE FROM CONTAPAGAR
                        WHERE CDFILIAL = @P_CDFILIAL
                          AND NRLANCTONF = @P_NRLANCTONF;

                        DECLARE C_ITEMTRAB CURSOR FOR
                           SELECT DTVENCIMENTO, VRVENCIMENTO, QTDIASVENC, NRSEQVENC
                             FROM TRAB_VENCIMENTO
                            WHERE CDFILIALVENC = @P_CDFILIAL
                              AND NRLANCTONFVENC = @P_NRLANCTONF
                            ORDER BY NRSEQVENC;
                        OPEN C_ITEMTRAB;
                        FETCH NEXT FROM C_ITEMTRAB INTO
                        @V_ITEM_DTVENCIMENTO,
                        @V_ITEM_VRPAGO,
                        @V_ITEM_QTDIAS,
                        @V_ITEM_NRSEQUENCIAL;
                        /*PESQUISA OS VENCIMENTOS GERADOS*/
                        WHILE (@@FETCH_STATUS = 0) BEGIN
                           SET @V_VRVENCACUM = 0;
                           SET @V_COUNT = 1;

                           /*SE NO TIVER TIPO DE CONTA PARAMETRIZADA NA AF*/
                           IF (@V_TPCONTAPAG_AF IS NULL OR
                              @V_COUNTTPCONTA_AF > 1 ) BEGIN
                              /*BUSCA PARAMETRIZAO DE TIPO DE CONTA POR PRODUTO DA NOTA*/
                              DECLARE C_TP_CONTA_PROD_PAG CURSOR FOR
                                 SELECT ISNULL(P.CDTPCTPAGAR, X.CDTPCTPAGAR) CDTPCTPAGAR , TP.CDCLASSFINA, TP.DSDEFACTPAG, SUM(I.VRBRUTITEM) AS VRBRUTITEM 
                                   FROM PRODUTO P,
                                        ITEMPRODUTO I LEFT JOIN (SELECT P.CDARVPROD, P.CDPRODUTO, P1.CDTPCTPAGAR
                                                                   FROM ITEMPRODUTO I, PRODUTO P, PRODUTO P1
                                                                  WHERE I.CDFILIAL = @P_CDFILIAL
                                                                    AND I.NRLANCTONF = @P_NRLANCTONF
                                                                    AND I.CDPRODUTO = P.CDPRODUTO
                                                                    AND P1.CDARVPROD = (SELECT MAX(E.CDARVPROD)
                                                                                          FROM PRODUTO E
                                                                                          WHERE CDTPCTPAGAR IS NOT NULL
                                                                                            AND (CHARINDEX(E.CDARVPROD, P.CDARVPROD) = 1))) X
                                                                ON I.CDPRODUTO = X.CDPRODUTO
                                                         LEFT JOIN TIPOCTPAGAR TP
                                                                ON X.CDTPCTPAGAR = TP.CDTPCTPAGAR

                                  WHERE I.CDFILIAL = @P_CDFILIAL
                                    AND I.NRLANCTONF = @P_NRLANCTONF
                                    AND I.CDPRODUTO = P.CDPRODUTO
                                 GROUP BY ISNULL(P.CDTPCTPAGAR, X.CDTPCTPAGAR), TP.CDCLASSFINA, TP.DSDEFACTPAG;
                                 
                              OPEN C_TP_CONTA_PROD_PAG;
                              FETCH NEXT FROM C_TP_CONTA_PROD_PAG INTO
                              @V_PROD_TPCTPAG,
                              @V_PROD_CDCLASSFIN,
                              @V_PROD_DSDEFACTPAG,
                              @V_PROD_VRBRUTITEM;

                              SELECT @V_ROW_COUNT = COUNT(*)
                                FROM (SELECT ISNULL(P.CDTPCTPAGAR, X.CDTPCTPAGAR) CDTPCTPAGAR , TP.CDCLASSFINA, TP.DSDEFACTPAG, SUM(I.VRBRUTITEM) AS VRBRUTITEM
                                        FROM PRODUTO P,
                                             ITEMPRODUTO I LEFT JOIN (SELECT P.CDARVPROD, P.CDPRODUTO, P1.CDTPCTPAGAR
                                                                        FROM ITEMPRODUTO I, PRODUTO P, PRODUTO P1
                                                                       WHERE I.CDFILIAL = @P_CDFILIAL
                                                                         AND I.NRLANCTONF = @P_NRLANCTONF
                                                                         AND I.CDPRODUTO = P.CDPRODUTO
                                                                         AND P1.CDARVPROD = (SELECT MAX(E.CDARVPROD)
                                                                                               FROM PRODUTO E
                                                                                               WHERE CDTPCTPAGAR IS NOT NULL
                                                                                                 AND (CHARINDEX(E.CDARVPROD, P.CDARVPROD) = 1))) X
                                                                     ON I.CDPRODUTO = X.CDPRODUTO
                                                              LEFT JOIN TIPOCTPAGAR TP
                                                                     ON X.CDTPCTPAGAR = TP.CDTPCTPAGAR

                                       WHERE I.CDFILIAL = @P_CDFILIAL
                                         AND I.NRLANCTONF = @P_NRLANCTONF
                                         AND I.CDPRODUTO = P.CDPRODUTO
                                      GROUP BY ISNULL(P.CDTPCTPAGAR, X.CDTPCTPAGAR), TP.CDCLASSFINA, TP.DSDEFACTPAG
                                      ) A;

                              WHILE (@@FETCH_STATUS = 0) BEGIN
                                  /*CLCULO DO VALOR DO VENCIMENTO PARA O TIPO DE CONTA, PROPORCIONALMENTE AO VENCIMENTO J GERADO E AO VALOR BRUTO DO ITEM*/
                                  SET @V_VRVENCIMENTO = ROUND(@V_PROD_VRBRUTITEM * (@V_ITEM_VRPAGO/@V_VRNOTAFISC), 2);
                                  /*CLCULO DO VALOR PROPORCIONAL DO IMPOSTO PARA O VALOR DE VENCIMENTO INFORMADO*/
                                  SET @V_VRIMPOSTO = ROUND(@V_VRIMPORETI * (@V_VRVENCIMENTO/(@V_VRNOTAFISC + @V_VRIMPORETI)), 2);
                                  /*VALOR DO VENCIMENTO J CONSIDERANDO O VALOR DO IMPOSTO*/
                                  SET @V_VRVENCIMENTO = @V_VRVENCIMENTO - @V_VRIMPOSTO;
                                  /*VALOR ACUMULATIVO DO VENCIMENTO*/
                                  SET @V_VRVENCACUM = @V_VRVENCACUM + @V_VRVENCIMENTO;
                                  /*VERIFICA SE AINDA EXISTE VALOR DO VENCIMENTO ORIGINAL A SER INSERIDO*/
                                  IF (@V_COUNT = @V_ROW_COUNT) BEGIN
                                     SET @V_VRVENCIMENTO = @V_VRVENCIMENTO + ROUND(@V_ITEM_VRPAGO - @V_VRVENCACUM, 2);
                                  END;
                                  /*INCLUI AS CONTA A PAGAR*/
                                  INSERT INTO CONTAPAGAR
                                     (CDFILIAL, NRLANCTONF, CDMOTIPROR, CDMOTIPARC, CDTPCTPAGAR, NRSEQVENPAG,
                                      NRPARCELAPAG, QTDIASVENPAG, DTORIGVENPAG, VRORIGPAG, DTATUAVENPAG, VRATUAPAG,
                                      IDSTATPAG, DSCONTAPAG, CDFILIBPAG, NRLANBOLPAG)
                                  VALUES
                                     (@P_CDFILIAL, @P_NRLANCTONF, NULL, NULL, @V_PROD_TPCTPAG, RIGHT(REPLICATE('0',2) + CONVERT(VARCHAR, @V_SEQUENCIAL),2),  '00', @V_ITEM_QTDIAS,
                                      @V_ITEM_DTVENCIMENTO, @V_VRVENCIMENTO, @V_ITEM_DTVENCIMENTO , @V_VRVENCIMENTO, 'A', NULL, NULL, NULL);

                                  SET @V_COUNT = @V_COUNT + 1;
                                  SET @V_SEQUENCIAL = @V_SEQUENCIAL + 1;
                                  FETCH NEXT FROM C_TP_CONTA_PROD_PAG INTO
                                  @V_PROD_TPCTPAG,
                                  @V_PROD_CDCLASSFIN,
                                  @V_PROD_DSDEFACTPAG,
                                  @V_PROD_VRBRUTITEM;
                              END;
                              CLOSE C_TP_CONTA_PROD_PAG;
                              DEALLOCATE C_TP_CONTA_PROD_PAG;
                           END;

                           IF (@V_COUNT = 1) BEGIN
                              /*INCLUI AS CONTA A PAGAR*/
                              INSERT INTO CONTAPAGAR
                                 (CDFILIAL, NRLANCTONF, CDMOTIPROR, CDMOTIPARC, CDTPCTPAGAR, NRSEQVENPAG,
                                  NRPARCELAPAG, QTDIASVENPAG, DTORIGVENPAG, VRORIGPAG, DTATUAVENPAG, VRATUAPAG,
                                  IDSTATPAG, DSCONTAPAG, CDFILIBPAG, NRLANBOLPAG)
                              VALUES
                                 (@P_CDFILIAL, @P_NRLANCTONF, NULL, NULL, @V_TPCONTAPAG_AF, SUBSTRING(@V_ITEM_NRSEQUENCIAL, LEN(@V_ITEM_NRSEQUENCIAL)-1, 2),  '00', @V_ITEM_QTDIAS,
                                  @V_ITEM_DTVENCIMENTO, @V_ITEM_VRPAGO, @V_ITEM_DTVENCIMENTO , @V_ITEM_VRPAGO, 'A', NULL, NULL, NULL);
                           END;
                           FETCH NEXT FROM C_ITEMTRAB INTO
                           @V_ITEM_DTVENCIMENTO,
                           @V_ITEM_VRPAGO,
                           @V_ITEM_QTDIAS,
                           @V_ITEM_NRSEQUENCIAL;
                        END;
                        CLOSE C_ITEMTRAB;
                        DEALLOCATE C_ITEMTRAB;
                     END
                     /*SE O DOCUMENTO POSSUI CONTAS A PAGAR*/
                     ELSE BEGIN
                        SET @V_SEQUENCIAL = 1;

                        DECLARE C_VENCIMENTOS CURSOR FOR
                        SELECT CDFILIAL, NRLANCTONF, NRPARCELAPAG,
                               QTDIASVENPAG, DTORIGVENPAG, SUM(VRORIGPAG) AS VRORIGPAG,
                               DSCONTAPAG, DTATUAVENPAG, SUM(VRATUAPAG) AS VRATUAPAG,
                               IDSTATPAG, CDCLASSFINA, CT.VRATUAPAGTOT,
                               IMPRET.VRTOTIMPONF
                          FROM CONTAPAGAR IT,
                               (SELECT SUM(VRATUAPAG) AS VRATUAPAGTOT
                                  FROM CONTAPAGAR
                                 WHERE CDFILIAL = @P_CDFILIAL
                                   AND NRLANCTONF = @P_NRLANCTONF) CT,
                               (SELECT SUM(A.VRTOTIMPONF) AS VRTOTIMPONF
                                  FROM IMPOSNFTOT A, IMPOSTO B
                                 WHERE A.CDFILIAL   = @P_CDFILIAL
                                   AND A.NRLANCTONF = @P_NRLANCTONF
                                   AND B.IDTRATIMPO = 'R'
                                   AND B.IDDESCRFONTE = 'R'
                                   AND A.CDIMPOSTO  = B.CDIMPOSTO) IMPRET
                         WHERE IT.CDFILIAL = @P_CDFILIAL
                           AND IT.NRLANCTONF = @P_NRLANCTONF
                         GROUP BY CDFILIAL, NRLANCTONF, NRPARCELAPAG,
                                  QTDIASVENPAG, DTORIGVENPAG, DSCONTAPAG,
                                  DTATUAVENPAG, IDSTATPAG, CDCLASSFINA,
                                  CT.VRATUAPAGTOT, IMPRET.VRTOTIMPONF
                         ORDER BY DTORIGVENPAG;
                        OPEN C_VENCIMENTOS;
                        FETCH NEXT FROM C_VENCIMENTOS INTO
                        @V_CNT_CDFILIAL,
                        @V_CNT_NRLANCTONF,
                        @V_CNT_NRPARCELAPAG,
                        @V_CNT_QTDIASVENPAG,
                        @V_CNT_DTORIGVENPAG,
                        @V_CNT_VRORIGPAG,
                        @V_CNT_DSCONTAPAG,
                        @V_CNT_DTATUAVENPAG,
                        @V_CNT_VRATUAPAG,
                        @V_CNT_IDSTATPAG,
                        @V_CNT_CDCLASSFINA,
                        @V_CNT_VRATUAPAGTOT,
                        @V_CNT_VRTOTIMPONF;

                        /*APAGA AS CONTAS A PAGAR RELACIONADAS  NOTAFISCAL*/
                        DELETE FROM CONTAPAGAR
                        WHERE CDFILIAL = @P_CDFILIAL
                          AND NRLANCTONF = @P_NRLANCTONF;

                        WHILE (@@FETCH_STATUS = 0) BEGIN
                           SET @V_VRVENCACUM = 0;
                           SET @V_COUNT = 1;

                           IF (@V_TPCONTAPAG_AF IS NULL OR
                               @V_COUNTTPCONTA_AF > 1 ) BEGIN
                              /*BUSCA PARAMETRIZAO DE TIPO DE CONTA POR PRODUTO DA NOTA*/
                              DECLARE C_TP_CONTA_PROD_PAG CURSOR FOR
                                 SELECT ISNULL(P.CDTPCTPAGAR, X.CDTPCTPAGAR) CDTPCTPAGAR , TP.CDCLASSFINA, TP.DSDEFACTPAG, SUM(I.VRBRUTITEM) AS VRBRUTITEM 
                                   FROM PRODUTO P,
                                        ITEMPRODUTO I LEFT JOIN (SELECT P.CDARVPROD, P.CDPRODUTO, P1.CDTPCTPAGAR
                                                                   FROM ITEMPRODUTO I, PRODUTO P, PRODUTO P1
                                                                  WHERE I.CDFILIAL = @P_CDFILIAL
                                                                    AND I.NRLANCTONF = @P_NRLANCTONF
                                                                    AND I.CDPRODUTO = P.CDPRODUTO
                                                                    AND P1.CDARVPROD = (SELECT MAX(E.CDARVPROD)
                                                                                          FROM PRODUTO E
                                                                                          WHERE CDTPCTPAGAR IS NOT NULL
                                                                                            AND (CHARINDEX(E.CDARVPROD, P.CDARVPROD) = 1))) X
                                                                ON I.CDPRODUTO = X.CDPRODUTO
                                                         LEFT JOIN TIPOCTPAGAR TP
                                                                ON X.CDTPCTPAGAR = TP.CDTPCTPAGAR

                                  WHERE I.CDFILIAL = @P_CDFILIAL
                                    AND I.NRLANCTONF = @P_NRLANCTONF
                                    AND I.CDPRODUTO = P.CDPRODUTO
                                 GROUP BY ISNULL(P.CDTPCTPAGAR, X.CDTPCTPAGAR), TP.CDCLASSFINA, TP.DSDEFACTPAG;
                                 
                              OPEN C_TP_CONTA_PROD_PAG;
                              FETCH NEXT FROM C_TP_CONTA_PROD_PAG INTO
                              @V_PROD_TPCTPAG,
                              @V_PROD_CDCLASSFIN,
                              @V_PROD_DSDEFACTPAG,
                              @V_PROD_VRBRUTITEM;

                              SELECT @V_ROW_COUNT = COUNT(*)
                                FROM (SELECT ISNULL(P.CDTPCTPAGAR, X.CDTPCTPAGAR) CDTPCTPAGAR , TP.CDCLASSFINA, TP.DSDEFACTPAG, SUM(I.VRBRUTITEM) AS VRBRUTITEM
                                       FROM PRODUTO P,
                                            ITEMPRODUTO I LEFT JOIN (SELECT P.CDARVPROD, P.CDPRODUTO, P1.CDTPCTPAGAR
                                                                       FROM ITEMPRODUTO I, PRODUTO P, PRODUTO P1
                                                                      WHERE I.CDFILIAL = @P_CDFILIAL
                                                                        AND I.NRLANCTONF = @P_NRLANCTONF
                                                                        AND I.CDPRODUTO = P.CDPRODUTO
                                                                        AND P1.CDARVPROD = (SELECT MAX(E.CDARVPROD)
                                                                                              FROM PRODUTO E
                                                                                              WHERE CDTPCTPAGAR IS NOT NULL
                                                                                                AND (CHARINDEX(E.CDARVPROD, P.CDARVPROD) = 1))) X
                                                                    ON I.CDPRODUTO = X.CDPRODUTO
                                                             LEFT JOIN TIPOCTPAGAR TP
                                                                    ON X.CDTPCTPAGAR = TP.CDTPCTPAGAR

                                      WHERE I.CDFILIAL = @P_CDFILIAL
                                        AND I.NRLANCTONF = @P_NRLANCTONF
                                        AND I.CDPRODUTO = P.CDPRODUTO
                                     GROUP BY ISNULL(P.CDTPCTPAGAR, X.CDTPCTPAGAR), TP.CDCLASSFINA, TP.DSDEFACTPAG
                                     ) A;

                              WHILE (@@FETCH_STATUS = 0) BEGIN
                                  /*CLCULO DO VALOR DO VENCIMENTO PARA O TIPO DE CONTA, PROPORCIONALMENTE AO VENCIMENTO J GERADO E AO VALOR BRUTO DO ITEM*/
                                  SET @V_VRVENCIMENTO = ROUND(@V_PROD_VRBRUTITEM * (@V_CNT_VRATUAPAG/@V_VRNOTAFISC), 2);
                                  /*CLCULO DO VALOR PROPORCIONAL DO IMPOSTO PARA O VALOR DE VENCIMENTO INFORMADO*/
                                  SET @V_VRIMPOSTO = ROUND(@V_VRIMPORETI * (@V_VRVENCIMENTO/(@V_VRNOTAFISC + @V_VRIMPORETI)), 2);
                                  /*VALOR DO VENCIMENTO J CONSIDERANDO O VALOR DO IMPOSTO*/
                                  SET @V_VRVENCIMENTO = @V_VRVENCIMENTO - @V_VRIMPOSTO;
                                  /*VALOR ACUMULATIVO DO VENCIMENTO*/
                                  SET @V_VRVENCACUM = @V_VRVENCACUM + @V_VRVENCIMENTO;
                                  /*VERIFICA SE AINDA EXISTE VALOR DO VENCIMENTO ORIGINAL A SER INSERIDO*/
                                  IF (@V_COUNT = @V_ROW_COUNT) BEGIN
                                     SET @V_VRVENCIMENTO = @V_VRVENCIMENTO + ROUND(@V_CNT_VRATUAPAG - @V_VRVENCACUM, 2);
                                  END;
                                  /*INCLUI AS CONTA A PAGAR*/
                                  INSERT INTO CONTAPAGAR
                                     (CDFILIAL, NRLANCTONF, CDMOTIPROR, CDMOTIPARC, CDTPCTPAGAR, NRSEQVENPAG,
                                      NRPARCELAPAG, QTDIASVENPAG, DTORIGVENPAG, VRORIGPAG, DTATUAVENPAG, VRATUAPAG,
                                      IDSTATPAG, DSCONTAPAG, CDFILIBPAG, NRLANBOLPAG)
                                  VALUES
                                     (@P_CDFILIAL, @P_NRLANCTONF, NULL, NULL, @V_PROD_TPCTPAG, RIGHT(REPLICATE('0',2) + CONVERT(VARCHAR, @V_SEQUENCIAL),2),  '00', @V_CNT_QTDIASVENPAG,
                                      @V_CNT_DTATUAVENPAG, @V_VRVENCIMENTO, @V_CNT_DTATUAVENPAG , @V_VRVENCIMENTO, 'A', @V_CNT_DSCONTAPAG, NULL, NULL);

                                  SET @V_COUNT = @V_COUNT + 1;
                                  SET @V_SEQUENCIAL = @V_SEQUENCIAL + 1;
                                  FETCH NEXT FROM C_TP_CONTA_PROD_PAG INTO
                                  @V_PROD_TPCTPAG,
                                  @V_PROD_CDCLASSFIN,
                                  @V_PROD_DSDEFACTPAG,
                                  @V_PROD_VRBRUTITEM;
                              END;
                              CLOSE C_TP_CONTA_PROD_PAG;
                              DEALLOCATE C_TP_CONTA_PROD_PAG;
                           END;

                           IF (@V_COUNT = 1) BEGIN
                              /*INCLUI AS CONTA A PAGAR*/
                              INSERT INTO CONTAPAGAR
                                 (CDFILIAL, NRLANCTONF, CDMOTIPROR, CDMOTIPARC, CDTPCTPAGAR, NRSEQVENPAG,
                                  NRPARCELAPAG, QTDIASVENPAG, DTORIGVENPAG, VRORIGPAG, DTATUAVENPAG, VRATUAPAG,
                                  IDSTATPAG, DSCONTAPAG, CDFILIBPAG, NRLANBOLPAG)
                              VALUES
                                 (@P_CDFILIAL, @P_NRLANCTONF, NULL, NULL, @V_TPCONTAPAG_AF, RIGHT(REPLICATE('0',2) + CONVERT(VARCHAR, @V_SEQUENCIAL),2),  '00', @V_CNT_QTDIASVENPAG,
                                  @V_CNT_DTATUAVENPAG, @V_CNT_VRATUAPAG, @V_CNT_DTATUAVENPAG, @V_CNT_VRATUAPAG, 'A', @V_CNT_DSCONTAPAG, NULL, NULL);
                              SET @V_SEQUENCIAL = @V_SEQUENCIAL + 1;
                           END;

                           FETCH NEXT FROM C_VENCIMENTOS INTO
                           @V_CNT_CDFILIAL,
                           @V_CNT_NRLANCTONF,
                           @V_CNT_NRPARCELAPAG,
                           @V_CNT_QTDIASVENPAG,
                           @V_CNT_DTORIGVENPAG,
                           @V_CNT_VRORIGPAG,
                           @V_CNT_DSCONTAPAG,
                           @V_CNT_DTATUAVENPAG,
                           @V_CNT_VRATUAPAG,
                           @V_CNT_IDSTATPAG,
                           @V_CNT_CDCLASSFINA,
                           @V_CNT_VRATUAPAGTOT,
                           @V_CNT_VRTOTIMPONF;
                        END;
                        CLOSE C_VENCIMENTOS;
                        DEALLOCATE C_VENCIMENTOS;
                     END;
                  END;

                  DECLARE C_ITEMNOTA CURSOR FOR SELECT CDFILIALIT, NRLANCTONFIT
                                                  FROM ITEMNOTAFISC
                                                 WHERE CDFILIAL   = @P_CDFILIAL
                                                   AND NRLANCTONF = @P_NRLANCTONF;
                  OPEN C_ITEMNOTA;
                  FETCH NEXT FROM C_ITEMNOTA INTO @V_ITEMNOTA_CDFILIALIT, @V_ITEMNOTA_NRLANCTONFIT;

                  /*ATUALIZAO DAS CONTAS A PAGAR RELACIONADAS  AUTORIZAO DE FORNECIMENTO*/
                  WHILE (@@FETCH_STATUS = 0) BEGIN
                     EXEC AJUSTE_CONTAPAGAR_NF @V_ITEMNOTA_CDFILIALIT,
                                               @V_ITEMNOTA_NRLANCTONFIT,
                                               'A';

                     FETCH NEXT FROM C_ITEMNOTA INTO @V_ITEMNOTA_CDFILIALIT, @V_ITEMNOTA_NRLANCTONFIT;
                  END;
                  CLOSE C_ITEMNOTA;
                  DEALLOCATE C_ITEMNOTA;

                  /*ATUALIZAO DAS CONTAS A PAGAR RELACIONADAS  AUTORIZAO DE FORNECIMENTO*/
                  EXEC AJUSTE_CONTAPAGAR_NF @P_CDFILIAL,
                                            @P_NRLANCTONF,
                                            'A';

                  /*BUSCA AS CONTAS A PAGAR DO DOCUMENTO*/
                  DECLARE C_CONTAPAGAR CURSOR FOR
                     SELECT CDFILIAL, NRLANCTONF, NRSEQVENPAG, NRPARCELAPAG,
                            QTDIASVENPAG, DTORIGVENPAG, VRORIGPAG, CDTPCTPAGAR,
                            DTATUAVENPAG, VRATUAPAG, IDSTATPAG, NRLANBOLPAG,
                            CDFILIBPAG, CDCLASSFINA, DTMOVFLUXO, IDMOVFLUXO,
                            CDFIMOVFLPAG, CDEMPRESA, DSCONTAPAG
                       FROM CONTAPAGAR
                      WHERE CDFILIAL = @P_CDFILIAL
                        AND NRLANCTONF = @P_NRLANCTONF
                      ORDER BY CDFILIAL, NRLANCTONF, DTATUAVENPAG;
                  OPEN C_CONTAPAGAR;
                  FETCH NEXT FROM C_CONTAPAGAR INTO
                  @V_CNT_CDFILIAL,
                  @V_CNT_NRLANCTONF,
                  @V_CNT_NRSEQVENPAG,
                  @V_CNT_NRPARCELAPAG,
                  @V_CNT_QTDIASVENPAG,
                  @V_CNT_DTORIGVENPAG,
                  @V_CNT_VRORIGPAG,
                  @V_CNT_CDTPCTPAGAR,
                  @V_CNT_DTATUAVENPAG,
                  @V_CNT_VRATUAPAG,
                  @V_CNT_IDSTATPAG,
                  @V_CNT_NRLANBOLPAG,
                  @V_CNT_CDFILIBPAG,
                  @V_CNT_CDCLASSFINA,
                  @V_CNT_DTMOVFLUXO,
                  @V_CNT_IDMOVFLUXO,
                  @V_CNT_CDFIMOVFLPAG,
                  @V_CNT_CDEMPRESA,
                  @V_CNT_DSCONTAPAG;

                  IF (@@FETCH_STATUS = 0) BEGIN
                     /*BUSCA PARAMETRIZAO DA EMPRESA*/
                     SELECT @V_EMPR_VRPEMOREMPR = E.VRPEMOREMPR,
                            @V_EMPR_VRPEMULEMPR = E.VRPEMULEMPR,
                            @V_EMPR_CDTPBAIXAPAG = PE.CDTPBAIXAPAG,
                            @V_EMPR_CDTPBAIXAREC = PE.CDTPBAIXAREC,
                            @V_EMPR_CDREDUCONT = PE.CDREDUCONTPAG
                       FROM EMPRESA E LEFT JOIN PARAMEMPRESA PE
                            ON (E.CDEMPRESA = PE.CDEMPRESA)
                      WHERE E.CDEMPRESA = @V_CDEMPRESA;
                     /*BUSCA PARAMETRIZAO DA FILIAL*/
                     SELECT @V_FIL_CDTPBAIXAPAG = CDTPBAIXAPAG,
                            @V_FIL_CDTPBAIXAREC = CDTPBAIXAREC,
                            @V_FIL_CDREDUCONTPAG = CDREDUCONTPAG,
                            @V_FIL_IDCONDESBONFORN = ISNULL(IDCONDESBONFORN,'S')
                       FROM PARAMFILIAL
                      WHERE CDFILIAL = @V_CDFILIRECE;
                     /*BUSCA PARAMETRIZAO DO FORNECEDOR*/
                     SELECT @V_FORN_CDFORNECED = F.CDFORNECED,
                            @V_FORN_IDAGRUBOLFOR = F.IDAGRUBOLFOR,
                            @V_FORN_CDBANCFORN = C.CDBANCFORN,
                            @V_FORN_CDAGENFORN = C.CDAGENFORN,
                            @V_FORN_CDCCORFORN = C.CDCCORFORN,
                            @V_FORN_IDCCORFORNPREF = C.IDCCORFORNPREF,
                            @V_FORN_CDTPBAIXAPAG = F.CDTPBAIXAPAG,
                            @V_FORN_CDTPCTPAGAR = F.CDTPCTPAGAR
                       FROM FORNECEDOR F LEFT JOIN
                            (SELECT CDFORNECED, CDBANCFORN, CDAGENFORN, CDCCORFORN, IDCCORFORNPREF
                               FROM CCORFORN
                              WHERE IDCCORFORNPREF = 'S'
                                AND CDFORNECED = @V_CDFORNECED) C
                            ON (F.CDFORNECED   = C.CDFORNECED)
                      WHERE (F.CDFORNECED   = @V_CDFORNECED);

                     /*VERIFICA PARAMETRIZAO DE TIPO DE BAIXA*/
                     IF @V_FORN_CDTPBAIXAPAG IS NULL BEGIN
                        IF @V_FIL_CDTPBAIXAPAG IS NULL BEGIN
                           SET @V_CDTPBAIXAPAG = @V_EMPR_CDTPBAIXAPAG;
                        END
                        ELSE BEGIN
                           SET @V_CDTPBAIXAPAG = @V_FIL_CDTPBAIXAPAG;
                        END;
                     END
                     ELSE BEGIN
                        SET @V_CDTPBAIXAPAG = @V_FORN_CDTPBAIXAPAG;
                     END;

                     /*VERIFICA PARAMETRIZAO DE CONTA CORRENTE*/
                     IF @V_FIL_CDREDUCONTPAG IS NULL BEGIN
                        SET @V_CDREDUCONT = @V_EMPR_CDREDUCONT;
                     END
                     ELSE BEGIN
                        SET @V_CDREDUCONT = @V_FIL_CDREDUCONTPAG;
                     END;

                     /*VERIFICA CONTA CORRENTE PREFERENCIAL DO FORNECEDOR*/
                     SELECT @V_IDBAIXAUTIL = IDBAIXAUTILP
                       FROM  TIPOBAIXAPAG
                      WHERE CDTPBAIXAPAG = @V_CDTPBAIXAPAG;

                     /*SE FOR BOLETO BANCRIO, A CONTA CORRENTE  RETIRADA DA LINHA DIGITVEL*/
                     IF @V_IDBAIXAUTIL = 'B' BEGIN
                        SET @V_CDBANCFORN = NULL;
                        SET @V_CDAGENFORN = NULL;
                        SET @V_CDCCORFORN = NULL;
                     END
                     ELSE BEGIN
                        SET @V_CDBANCFORN = @V_FORN_CDBANCFORN;
                        SET @V_CDAGENFORN = @V_FORN_CDAGENFORN;
                        SET @V_CDCCORFORN = @V_FORN_CDCCORFORN;
                     END;
                     /*CONSIDERA AJUSTE DE BONIFICAO*/
                     SET @V_IDCONDESBONFORN = @V_FIL_IDCONDESBONFORN;
                     /*VERIFICA CADA CONTA A PAGAR, INSERINDO UM BOLETO E LIGANDO-A A ELE*/
                     WHILE (@@FETCH_STATUS = 0) BEGIN
                        /*VERIFICA TIPO DE CONTA DA CONTA A PAGAR*/
                        IF @V_CNT_CDTPCTPAGAR IS NULL BEGIN
                           SET @V_CDTPCTPAGAR = @V_TPOP_CDTPCTPAGAR;
                           IF @V_CDTPCTPAGAR IS NULL BEGIN
                              SET @V_CDTPCTPAGAR = @V_FORN_CDTPCTPAGAR;
                           END;
                        END
                        ELSE BEGIN
                           SET @V_CDTPCTPAGAR = @V_CNT_CDTPCTPAGAR;
                        END;
                        /*VERIFICA CLASSIFICAO FINANCEIRA*/
                        SELECT @V_CDCLASSFINA = CDCLASSFINA
                          FROM TIPOCTPAGAR
                         WHERE CDTPCTPAGAR = @V_CDTPCTPAGAR;
                        /*VERIFICA SE O VALOR DO VENCIMENTO NO SUPERA O VALOR ORADO*/
                        EXEC ORCAMENTO_OK @V_CDEMPRESA,
                                          @V_CDFILIRECE,
                                          @V_CDCLASSFINA,
                                          @V_CNT_DTATUAVENPAG,
                                          @V_CNT_VRORIGPAG,
                                          @V_ROW_COUNT OUTPUT;
                        IF @V_ROW_COUNT = 0 BEGIN
                           SET @P_RESULTADO = 'CNT_SUP_VRORC'; /*CONTA A PAGAR SUPERA O VALOR ORADO*/
                           RETURN;
                        END;

                        /*verifica se ja existe um boleto para a nota fiscal com a mesma data */
                        SELECT @V_CDFILIBOL = MAX(BP.CDFILIAL), @V_NRLANBOL = MAX(BP.NRLANBOLPAG)
                          FROM CONTAPAGAR CP, BOLETPAGAR BP
                         WHERE CP.CDFILIAL = @V_CNT_CDFILIAL
                           AND CP.NRLANCTONF = @V_CNT_NRLANCTONF
                           AND CP.CDFILIBPAG = BP.CDFILIAL
                           AND CP.NRLANBOLPAG = BP.NRLANBOLPAG
                           AND BP.DTVENBOLPAG = @V_CNT_DTATUAVENPAG;

                        IF (@V_CDFILIBOL IS NULL) AND (@V_NRLANBOL IS NULL) BEGIN
                           SET @V_CDFILIBOL = @P_CDFILIPROC;
                           /*BUSCA O NMERO DO PRXIMO BOLETO*/
                           SET @V_CHAVE = 'BOLETPAGAR'+@P_CDFILIPROC;
                           EXEC NOVO_CODIGO @V_CHAVE, @V_NRLANBOL OUTPUT, 1 ;
                           SET @V_NRLANBOL = SUBSTRING(@V_NRLANBOL, LEN(@V_NRLANBOL) - 9, 10);


                           /*Considera Feriado Bancario*/
                           SELECT @V_IDCOFERIBANC = MAX(IDCOFERIBANC)
                           FROM PARAMGERAL;

                           /*VERIFICA FERIADO BANCARIO CALENDRIO DA FILIAL DE RECEBIMENTO DA UNIDADE*/
                           IF @V_IDCOFERIBANC = 'S' BEGIN
                              DECLARE C_FERIBC CURSOR FOR
                               SELECT DTFERIBANC
                                 FROM FERIBANC
                               WHERE CDFILIAL = @V_CDFILIRECE
                                 AND DTFERIBANC >= @V_CNT_DTATUAVENPAG
                               ORDER BY DTFERIBANC

                              OPEN C_FERIBC;
                              FETCH NEXT FROM C_FERIBC INTO
                              @V_DTFERIBANC;

                              WHILE (@@FETCH_STATUS = 0) BEGIN
                                 IF @V_DTFERIBANC = @V_CNT_DTATUAVENPAG BEGIN
                                    SET @V_CNT_DTATUAVENPAG = @V_CNT_DTATUAVENPAG + 1;
                                 END
                                 ELSE BEGIN
                                    CLOSE C_FERIBC;
                                 END;
                                 FETCH NEXT FROM C_FERIBC INTO
                                 @V_DTFERIBANC;
                              END;

                              CLOSE C_FERIBC;
                              DEALLOCATE C_FERIBC;
                           END;


                           INSERT INTO BOLETPAGAR
                                  (CDFILIAL, NRLANBOLPAG, CDFORNECED,  CDEMPRESA,
                                  VRBOLPAG, VRFINALBPAG, DTVENBOLPAG, IDHABIBPAG,
                                  IDSTATBPAG,  VRPEMULBPAG, VRMULTABPAG,
                                  VRPEMORBPAG, VRMORDIABPAG, CDTPBAIXAPAG, CDREDUCONT,
                                  CDBANCBOLP, CDAGENBOLP, CDCCORBOLP, IDSITUCNABP, IDBPAGREAL, NRPARCBOLPAG)
                           VALUES (@V_CDFILIBOL, @V_NRLANBOL, @V_CDFORNECED,  @V_CDEMPRESA,
                                  0, 0, @V_CNT_DTATUAVENPAG, 'N', 'A',
                                  0, 0, 0, 0, @V_CDTPBAIXAPAG, @V_CDREDUCONT,
                                  @V_CDBANCFORN, @V_CDAGENFORN, @V_CDCCORFORN, '00', 'N', '00');
                        END;

                        /*ATUALIZA FLUXO DE CAIXA DO AJUSTE*/
                        EXEC ATUALIZA_FLUXO_DE_CAIXA @V_CDEMPRESA,
                                                     @V_CDFILIRECE,
                                                     @V_CNT_DTATUAVENPAG,
                                                     'E',
                                                     @V_CDCLASSFINA,
                                                     0,
                                                     @V_CNT_VRORIGPAG;
                        /*MONTA A DESCRIO DA CONTA A PAGAR*/
                        SELECT @V_NF_NRNOTAFISC = NF.NRNOTAFISC,
                               @V_NF_CDSERIEENTR = NF.CDSERIEENTR,
                               @V_NF_CDAJUCTPAG = F.CDAJUCTPAG,
                               @V_NF_IDTPIJURNF = NF.IDTPIJURNF,
                               @V_NF_NRINSJURNF = NF.NRINSJURNF,
                               @V_NF_NRNOTAFISCRELAC =
                               (SELECT MAX(N.NRNOTAFISC)
                                  FROM ITEMNOTAFISC I, NOTAFISCAL N
                                 WHERE I.CDFILIAL = @P_CDFILIAL AND
                                       I.NRLANCTONF = @P_NRLANCTONF AND
                                       I.CDFILIALIT = N.CDFILIAL AND
                                       I.NRLANCTONFIT = N.NRLANCTONF)
                          FROM NOTAFISCAL NF LEFT JOIN FORNECEDOR F
                               ON (NF.CDFORNECED = F.CDFORNECED)
                         WHERE CDFILIAL = @P_CDFILIAL AND
                               NRLANCTONF = @P_NRLANCTONF;

                        SET @V_DESCRICAO = @V_CNT_DSCONTAPAG;

                        IF @V_DESCRICAO IS NULL BEGIN
                           IF NOT (@V_NF_NRNOTAFISC IS NULL) AND NOT (@V_NF_CDSERIEENTR IS NULL) BEGIN
                              SET @V_DESCRICAO = 'NF: ' + @V_NF_NRINSJURNF + ' ' + @V_NF_NRNOTAFISC + ' - ' + @V_NF_CDSERIEENTR;
                           END
                           ELSE BEGIN
                              SET @V_DESCRICAO = 'NF: ' + @V_NF_NRINSJURNF + ' Seq: ' + @P_NRLANCTONF;
                           END;
                        END;
                        SET @V_DESCRICAO = REPLACE(@V_DESCRICAO, '[DCP]', ISNULL(@V_CNT_DSCONTAPAG, ''));
                        SET @V_DESCRICAO = REPLACE(@V_DESCRICAO, '[TCP]', ISNULL(@V_CDTPCTPAGAR, ''));
                        SET @V_DESCRICAO = REPLACE(@V_DESCRICAO, '[TAP]', ISNULL(@V_NF_CDAJUCTPAG, ''));
                        SET @V_DESCRICAO = REPLACE(@V_DESCRICAO, '[DAP]', ' ');
                        SET @V_DESCRICAO = REPLACE(@V_DESCRICAO, '[DOCO]', ISNULL(@V_NF_NRNOTAFISCRELAC, ''));

                        /*ATUALIZA A CONTA A PAGAR, LIGANDO O BOLETO*/
                        UPDATE CONTAPAGAR
                           SET CDFILIBPAG = @V_CDFILIBOL,
                               NRLANBOLPAG = @V_NRLANBOL,
                               CDTPCTPAGAR = @V_CDTPCTPAGAR,
                               CDEMPRESA = @V_CDEMPRESA,
                               CDFIMOVFLPAG = @V_CDFILIRECE,
                               CDCLASSFINA = @V_CDCLASSFINA,
                               DTMOVFLUXO = @V_CNT_DTATUAVENPAG,
                               DTATUAVENPAG = @V_CNT_DTATUAVENPAG,
                               IDMOVFLUXO = 'E',
                               DSCONTAPAG = SUBSTRING(@V_DESCRICAO, 1, 200)
                          WHERE CDFILIAL = @V_CNT_CDFILIAL
                            AND NRLANCTONF = @V_CNT_NRLANCTONF
                            AND NRSEQVENPAG = @V_CNT_NRSEQVENPAG
                            AND NRPARCELAPAG = @V_CNT_NRPARCELAPAG;

                        /*ATUALIZA O VALOR DO BOLETO*/
                        UPDATE BOLETPAGAR
                           SET VRBOLPAG = (SELECT ROUND(SUM(VRATUAPAG),2)
                                             FROM CONTAPAGAR
                                            WHERE CDFILIBPAG  = @V_CDFILIBOL
                                              AND NRLANBOLPAG = @V_NRLANBOL),
                               VRFINALBPAG = (SELECT ROUND(SUM(VRATUAPAG),2)
                                                FROM CONTAPAGAR
                                               WHERE CDFILIBPAG  = @V_CDFILIBOL
                                                 AND NRLANBOLPAG = @V_NRLANBOL),
                               IDBPAGREAL = 'N',
                               CDBARRAPAG = NULL,
                               DSLINHBARPAG = NULL
                         WHERE CDFILIAL = @V_CDFILIBOL
                           AND NRLANBOLPAG = SUBSTRING(@V_NRLANBOL, LEN(@V_NRLANBOL) - 9, 10);
                        FETCH NEXT FROM C_CONTAPAGAR INTO
                        @V_CNT_CDFILIAL,
                        @V_CNT_NRLANCTONF,
                        @V_CNT_NRSEQVENPAG,
                        @V_CNT_NRPARCELAPAG,
                        @V_CNT_QTDIASVENPAG,
                        @V_CNT_DTORIGVENPAG,
                        @V_CNT_VRORIGPAG,
                        @V_CNT_CDTPCTPAGAR,
                        @V_CNT_DTATUAVENPAG,
                        @V_CNT_VRATUAPAG,
                        @V_CNT_IDSTATPAG,
                        @V_CNT_NRLANBOLPAG,
                        @V_CNT_CDFILIBPAG,
                        @V_CNT_CDCLASSFINA,
                        @V_CNT_DTMOVFLUXO,
                        @V_CNT_IDMOVFLUXO,
                        @V_CNT_CDFIMOVFLPAG,
                        @V_CNT_CDEMPRESA,
                        @V_CNT_DSCONTAPAG;
                     END;
                  END;
                  CLOSE C_CONTAPAGAR;
                  DEALLOCATE C_CONTAPAGAR;
                  /*GERA AJUSTES RETIDOS NA FONTE*/
                  EXEC GERA_AJUSTE_BOLIMP @P_CDFILIAL,
                                          @P_NRLANCTONF,
                                          @V_CDFILIRECE;

                  /*INCLUI OS AJUSTES DE BONIFICAO DO FORNECEDOR*/
                  IF @V_IDCONDESBONFORN = 'S' BEGIN
                     /*BUSCA INFORMAES DO FORNECEDOR*/
                     SELECT @V_AJFORN_CDAJUCTPAG = F.CDAJUCTPAG,
                            @V_AJFORN_VRPEDESCFORN = F.VRPEDESCFORN,
                            @V_AJFORN_IDTPDESCFORN = F.IDTPDESCFORN,
                            @V_AJFORN_DTINIVRPDESC = F.DTINIVRPDESC,
                            @V_AJFORN_IDAJUCTPAG = T.IDAJUCTPAG
                       FROM FORNECEDOR F, TIPOAJPAGAR T
                      WHERE (T.CDAJUCTPAG   = F.CDAJUCTPAG)
                        AND (F.CDFORNECED = @V_CDFORNECED)
                        AND (F.VRPEDESCFORN IS NOT NULL)
                        AND F.IDTPDESCFORN = 'B';

                     /*CONFERE SE O FORNECEDOR UTILIZA DESCONTO DE BONIFICAO*/
                     IF @V_AJFORN_CDAJUCTPAG IS NOT NULL BEGIN
                        IF @V_AJFORN_IDAJUCTPAG = 'D' BEGIN
                           SET @V_FATOR = -1;
                        END
                        ELSE BEGIN
                           SET @V_FATOR = 1;
                        END;

                        /*BUSCA AS CONTAS A PAGAR DO DOCUMENTO*/
                        DECLARE C_CONTAPAGAR CURSOR FOR
                           SELECT CDFILIAL, NRLANCTONF, NRSEQVENPAG, NRPARCELAPAG,
                                  QTDIASVENPAG, DTORIGVENPAG, VRORIGPAG, CDTPCTPAGAR,
                                  DTATUAVENPAG, VRATUAPAG, IDSTATPAG, NRLANBOLPAG,
                                  CDFILIBPAG, CDCLASSFINA, DTMOVFLUXO, IDMOVFLUXO,
                                  CDFIMOVFLPAG, CDEMPRESA, DSCONTAPAG
                             FROM CONTAPAGAR
                            WHERE CDFILIAL = @P_CDFILIAL
                              AND NRLANCTONF = @P_NRLANCTONF
                            ORDER BY CDFILIAL, NRLANCTONF, DTATUAVENPAG;
                        OPEN C_CONTAPAGAR;
                        FETCH NEXT FROM C_CONTAPAGAR INTO
                        @V_CNT_CDFILIAL,
                        @V_CNT_NRLANCTONF,
                        @V_CNT_NRSEQVENPAG,
                        @V_CNT_NRPARCELAPAG,
                        @V_CNT_QTDIASVENPAG,
                        @V_CNT_DTORIGVENPAG,
                        @V_CNT_VRORIGPAG,
                        @V_CNT_CDTPCTPAGAR,
                        @V_CNT_DTATUAVENPAG,
                        @V_CNT_VRATUAPAG,
                        @V_CNT_IDSTATPAG,
                        @V_CNT_NRLANBOLPAG,
                        @V_CNT_CDFILIBPAG,
                        @V_CNT_CDCLASSFINA,
                        @V_CNT_DTMOVFLUXO,
                        @V_CNT_IDMOVFLUXO,
                        @V_CNT_CDFIMOVFLPAG,
                        @V_CNT_CDEMPRESA,
                        @V_CNT_DSCONTAPAG;

                        WHILE (@@FETCH_STATUS = 0) BEGIN
                           /*VERIFICA SE O VENCIMENTO DA CONTA EST SUPERIOR A DATA INICIAL PARA DESCONT*/
                           IF (@V_CNT_DTATUAVENPAG >= @V_AJFORN_DTINIVRPDESC) OR (@V_AJFORN_DTINIVRPDESC IS NULL) BEGIN
                              SET @V_VRDESCBONI = ROUND((@V_CNT_VRATUAPAG * @V_AJFORN_VRPEDESCFORN)/100, 2);
                              /*ATUALIZA FLUXO DE CAIXA DO AJUSTE*/
                              SET @V_COUNT = @V_VRDESCBONI * @V_FATOR;
                              EXEC ATUALIZA_FLUXO_DE_CAIXA @V_CDEMPRESA,
                                                           @V_CNT_CDFIMOVFLPAG,
                                                           @V_CNT_DTATUAVENPAG,
                                                           'E',
                                                           @V_CNT_CDCLASSFINA,
                                                           0,
                                                           @V_COUNT;
                              /*INSERE O AJUSTE*/
                              INSERT INTO AJCTPAGAR
                                    (CDFILIAL, NRLANCTONF, NRSEQVENPAG, NRPARCELAPAG, DTAJUSTEPAG, CDAJUCTPAG,
                                     DSAJUSTEPAG, VRAJUSTEPAG, CDCLASSFINA, CDEMMFAJCNTP, CDFIMFAJCNTP,
                                     DTMOVFLUXO, IDMOVFLUXO, CDECTBAJPAG, NRLCTBAJPAG)
                              VALUES
                                    (@V_CNT_CDFILIAL, @V_CNT_NRLANCTONF, @V_CNT_NRSEQVENPAG, @V_CNT_NRPARCELAPAG, @V_CNT_DTATUAVENPAG, @V_AJFORN_CDAJUCTPAG,
                                     'Ajuste', @V_VRDESCBONI, @V_CNT_CDCLASSFINA, @V_CDEMPRESA, @V_CNT_CDFIMOVFLPAG,
                                     @V_CNT_DTATUAVENPAG, 'E', '', '');

                              /*ATUALIZA O VALOR DA CONTA COM O AJUSTE GERADO*/
                              UPDATE CONTAPAGAR
                                 SET VRATUAPAG = VRATUAPAG + (@V_VRDESCBONI * @V_FATOR)
                               WHERE CDFILIAL = @V_CNT_CDFILIAL
                                 AND NRLANCTONF = @V_CNT_NRLANCTONF
                                 AND NRSEQVENPAG = @V_CNT_NRSEQVENPAG
                                 AND NRPARCELAPAG = @V_CNT_NRPARCELAPAG;

                              /*ATUALIZA O VALOR DO BOLETO COM O AJUSTE GERADO*/
                              UPDATE BOLETPAGAR
                                 SET VRFINALBPAG = VRFINALBPAG + (@V_VRDESCBONI * @V_FATOR),
                                     VRBOLPAG = VRBOLPAG + (@V_VRDESCBONI * @V_FATOR)
                               WHERE CDFILIAL = @V_CNT_CDFILIBPAG
                                 AND NRLANBOLPAG = @V_CNT_NRLANBOLPAG;
                           END;
                           FETCH NEXT FROM C_CONTAPAGAR INTO
                           @V_CNT_CDFILIAL,
                           @V_CNT_NRLANCTONF,
                           @V_CNT_NRSEQVENPAG,
                           @V_CNT_NRPARCELAPAG,
                           @V_CNT_QTDIASVENPAG,
                           @V_CNT_DTORIGVENPAG,
                           @V_CNT_VRORIGPAG,
                           @V_CNT_CDTPCTPAGAR,
                           @V_CNT_DTATUAVENPAG,
                           @V_CNT_VRATUAPAG,
                           @V_CNT_IDSTATPAG,
                           @V_CNT_NRLANBOLPAG,
                           @V_CNT_CDFILIBPAG,
                           @V_CNT_CDCLASSFINA,
                           @V_CNT_DTMOVFLUXO,
                           @V_CNT_IDMOVFLUXO,
                           @V_CNT_CDFIMOVFLPAG,
                           @V_CNT_CDEMPRESA,
                           @V_CNT_DSCONTAPAG;
                        END;
                        CLOSE C_CONTAPAGAR;
                        DEALLOCATE C_CONTAPAGAR;
                     END;
                  END;

                  /*GERA RATEIO DAS CONTAS A PAGAR*/
                  /*APAGA, CASO EXISTA, OS RATEIOS DA CONTA A PAGAR DA NOTA FISCAL*/

                  DELETE FROM RATCTPAGAR
                   WHERE CDFILIAL = @P_CDFILIAL
                     AND NRLANCTONF = @P_NRLANCTONF;
                  /*BUSCA AS CONTAS RELACIONADAS  NOTA FISCAL E INSERE RATEIO PARA CADA UMA DELAS*/
                  DECLARE C_CTPAG CURSOR FOR
                  SELECT CDFILIAL, NRLANCTONF, NRSEQVENPAG, NRPARCELAPAG, VRATUAPAG, CDTPCTPAGAR
                    FROM CONTAPAGAR
                   WHERE CDFILIAL = @P_CDFILIAL
                     AND NRLANCTONF = @P_NRLANCTONF;
                  OPEN C_CTPAG;
                  FETCH NEXT FROM C_CTPAG INTO

                  @V_CNT_CDFILIAL,
                  @V_CNT_NRLANCTONF,
                  @V_CNT_NRSEQVENPAG,
                  @V_CNT_NRPARCELAPAG,
                  @V_CNT_VRATUAPAG,
                  @V_CNT_CDTPCTPAGAR;

                  WHILE (@@FETCH_STATUS = 0) BEGIN
                     SET @V_VRPARCELA = 0;
                     SET @V_VRACUMULADO = 0;
                     SET @V_COUNT = 1;

                     SELECT @V_NRPARCELA = COUNT(*)
                       FROM RATEIONF
                      WHERE CDFILIAL = @P_CDFILIAL
                        AND NRLANCTONF = @P_NRLANCTONF;

                     IF @V_NRPARCELA > 0 BEGIN
                        DECLARE C_RATEIO CURSOR FOR
                         SELECT RT.CDFILIAL, RT.NRLANCTONF, RT.CDFILICCUST, RT.CDCENTCUSNF, ROUND(((SUM(RT.VRRATENF) * 100) / (CASE A.VRTOTAL WHEN 0 THEN 1 ELSE A.VRTOTAL END)), 2) AS VRPERCENTUAL
                           FROM RATEIONF RT, (SELECT SUM(VRRATENF) AS VRTOTAL
                                                FROM RATEIONF
                                               WHERE CDFILIAL = @P_CDFILIAL
                                                 AND NRLANCTONF = @P_NRLANCTONF) A
                          WHERE RT.CDFILIAL = @P_CDFILIAL
                            AND RT.NRLANCTONF = @P_NRLANCTONF
                         GROUP BY RT.CDFILIAL, RT.NRLANCTONF, RT.CDFILICCUST, RT.CDCENTCUSNF, A.VRTOTAL;

                        OPEN C_RATEIO;
                        FETCH NEXT FROM C_RATEIO INTO
                        @V_RAT_CDFILIALNF,
                        @V_RAT_NRLANCTONF,
                        @V_CDFILIAL,
                        @V_CDCENTCUST,
                        @V_VRRATEIOCTB;

                        WHILE (@@FETCH_STATUS = 0) BEGIN
                           SET @V_VRPARCELA = ROUND(((@V_CNT_VRATUAPAG * @V_VRRATEIOCTB) / 100), 2);

                           SET @V_VRACUMULADO = ROUND(@V_VRACUMULADO + @V_VRPARCELA, 2);

                           INSERT INTO RATCTPAGAR
                              (CDFILIAL, NRLANCTONF, NRSEQVENPAG, NRPARCELAPAG,
                               CDCENTCUST, CDFIRATCTPAG, VRRATCCCTPAG)
                           VALUES
                              (@V_CNT_CDFILIAL, @V_CNT_NRLANCTONF, @V_CNT_NRSEQVENPAG, @V_CNT_NRPARCELAPAG,
                               @V_CDCENTCUST, @V_CDFILIAL, @V_VRPARCELA);


                           FETCH NEXT FROM C_RATEIO INTO
                           @V_RAT_CDFILIALNF,
                           @V_RAT_NRLANCTONF,
                           @V_CDFILIAL,
                           @V_CDCENTCUST,
                           @V_VRRATEIOCTB;
                        END;

                        IF @V_VRACUMULADO <> @V_CNT_VRATUAPAG BEGIN
                           SET @V_VRACUMULADO = ROUND(@V_CNT_VRATUAPAG - @V_VRACUMULADO, 2);
                           UPDATE RATCTPAGAR
                              SET VRRATCCCTPAG = VRRATCCCTPAG + @V_VRACUMULADO
                            WHERE CDFILIAL = @V_CNT_CDFILIAL
                              AND NRLANCTONF = @V_CNT_NRLANCTONF
                              AND NRSEQVENPAG = @V_CNT_NRSEQVENPAG
                              AND NRPARCELAPAG = @V_CNT_NRPARCELAPAG
                              AND CDCENTCUST = @V_CDCENTCUST
                              AND CDFIRATCTPAG = @V_CDFILIAL;

                        END;
                        CLOSE C_RATEIO;
                        DEALLOCATE C_RATEIO;
                     END
                     ELSE BEGIN
                        SELECT @V_NRPARCELA = COUNT(*)
                          FROM RATTPCTP
                         WHERE CDTPCTPAGAR = @V_CNT_CDTPCTPAGAR;

                        IF @V_NRPARCELA > 0 BEGIN
                           DECLARE C_RATTPCTP CURSOR FOR
                           SELECT CDTPCTPAGAR, CDCENTCUST,
                                  (CASE CDFIRATTPCTP WHEN '----' THEN @V_CDFILIRECE ELSE CDFIRATTPCTP END) AS CDFIRATTPCTP,
                                  CDFILIAL, (VRPERATTPCTP/100) AS VRPERATTPCTP
                             FROM RATTPCTP
                            WHERE CDTPCTPAGAR = @V_CNT_CDTPCTPAGAR;
                           OPEN C_RATTPCTP;
                           FETCH NEXT FROM C_RATTPCTP INTO
                           @V_RAT_CDTPCONTA,
                           @V_RAT_CDCENTCUST,
                           @V_RAT_CDFIRATTPCT,
                           @V_RAT_CDFILIAL,
                           @V_RAT_VRPERATTPCT;

                           /*BUSCA INFORMAES DO PARMETRO PARA CENTRO DE CUSTO*/
                           WHILE (@@FETCH_STATUS = 0) BEGIN
                              SET @V_VRPARCELA = ROUND((@V_CNT_VRATUAPAG * @V_RAT_VRPERATTPCT),2);
                              SET @V_VRACUMULADO = @V_VRACUMULADO + @V_VRPARCELA;
                              IF @V_COUNT = @V_NRPARCELA BEGIN
                                 SET @V_VRPARCELA = @V_VRPARCELA + ROUND(@V_CNT_VRATUAPAG - @V_VRACUMULADO,2);
                              END;
                              IF NOT (@V_RAT_CDFIRATTPCT IS NULL) AND NOT (@V_RAT_CDCENTCUST IS NULL) BEGIN
                                 SELECT @V_ROW_COUNT = COUNT(*)
                                   FROM CENTCUSTFIL
                                  WHERE CDFILIAL = @V_RAT_CDFIRATTPCT
                                    AND CDCENTCUST = @V_RAT_CDCENTCUST;

                                 IF @V_ROW_COUNT > 0 BEGIN
                                    /*INSERE RATEIO PARA A CONTA A PAGAR*/
                                    INSERT INTO RATCTPAGAR
                                       (CDFILIAL, NRLANCTONF, NRSEQVENPAG, NRPARCELAPAG,
                                        CDCENTCUST, CDFIRATCTPAG, VRRATCCCTPAG)
                                    VALUES
                                       (@V_CNT_CDFILIAL, @V_CNT_NRLANCTONF, @V_CNT_NRSEQVENPAG, @V_CNT_NRPARCELAPAG,
                                        @V_RAT_CDCENTCUST, @V_RAT_CDFIRATTPCT, @V_VRPARCELA);
                                 END
                                 ELSE BEGIN
                                    /*CENTRO DE CUSTO (CDCENTCUST) NO CADASTRADO PARA A FILIAL (CDFILIAL)*/
                                    SET @P_RESULTADO = 'NOT_CENTCUSTFIL_' + @V_RAT_CDCENTCUST + @V_RAT_CDFIRATTPCT;
                                    RETURN;
                                 END;
                              END;
                              SET @V_COUNT = @V_COUNT + 1;
                              FETCH NEXT FROM C_RATTPCTP INTO
                              @V_RAT_CDTPCONTA,
                              @V_RAT_CDCENTCUST,
                              @V_RAT_CDFIRATTPCT,
                              @V_RAT_CDFILIAL,
                              @V_RAT_VRPERATTPCT;
                           END;
                           CLOSE C_RATTPCTP;
                           DEALLOCATE C_RATTPCTP;
                        END
                        ELSE BEGIN
                           /*BUSCA O CENTRO DE CUSTO DA FILIAL. SE NO PARAMETRIZADO, PEGA O DA EMPRESA*/
                           SELECT @V_CDFILIAL = MAX(CDFILIAL),
                                  @V_CDCENTCUST = MAX(CDCENTCUST)
                             FROM
                             (SELECT F.CDFILIAL, ISNULL(F.CDCENTCUST, E.CDCENTCUST) AS CDCENTCUST
                               FROM FILIAL F, EMPRESA E
                              WHERE F.CDFILIAL   = @V_CDFILIRECE AND
                                    E.CDEMPRESA  = @V_CDEMPRESA  AND
                                    F.CDEMPRESA  = E.CDEMPRESA
                              UNION
                             SELECT F.CDFILIAL, ISNULL(F.CDCENTCUST, E.CDCENTCUST) AS CDCENTCUST
                               FROM FILIAL F, EMPRESA E, EMPRCNTRFIL EC
                              WHERE EC.CDFILIAL   = @V_CDFILIRECE AND
                                    EC.CDEMPRESA  = @V_CDEMPRESA  AND
                                    E.CDEMPRESA   = EC.CDEMPRESA AND
                                    F.CDFILIAL = EC.CDFILIAL) SS;
                           SET @V_VRPARCELA = @V_CNT_VRATUAPAG;
                           IF NOT (@V_CDFILIAL IS NULL) AND NOT (@V_CDCENTCUST IS NULL) BEGIN
                              SELECT @V_ROW_COUNT = COUNT(*)
                                FROM CENTCUSTFIL
                               WHERE CDFILIAL = @V_CDFILIAL
                                 AND CDCENTCUST = @V_CDCENTCUST;
                              IF (@V_ROW_COUNT > 0) BEGIN
                                 /*INSERE RATEIO DA CONTA A PAGAR*/
                                 INSERT INTO RATCTPAGAR
                                      (CDFILIAL, NRLANCTONF, NRSEQVENPAG, NRPARCELAPAG,
                                       CDCENTCUST, CDFIRATCTPAG, VRRATCCCTPAG)
                                   VALUES
                                      (@V_CNT_CDFILIAL, @V_CNT_NRLANCTONF, @V_CNT_NRSEQVENPAG, @V_CNT_NRPARCELAPAG,
                                      @V_CDCENTCUST, @V_CDFILIAL, @V_VRPARCELA);
                              END
                              ELSE BEGIN
                                 /*CENTRO DE CUSTO (CDCENTCUST) NO CADASTRADO PARA A FILIAL (CDFILIAL)*/
                                 SET @P_RESULTADO = 'NOT_CENTCUSTFIL_' + @V_CDCENTCUST + @V_CDFILIAL;
                                 RETURN;
                              END;
                           END;
                        END;
                     END;
                     FETCH NEXT FROM C_CTPAG INTO
                     @V_CNT_CDFILIAL,
                     @V_CNT_NRLANCTONF,
                     @V_CNT_NRSEQVENPAG,
                     @V_CNT_NRPARCELAPAG,
                     @V_CNT_VRATUAPAG,
                     @V_CNT_CDTPCTPAGAR;
                  END;
                  CLOSE C_CTPAG;
                  DEALLOCATE C_CTPAG;
               END
               ELSE BEGIN
                  SET @P_RESULTADO = 'INV_TP_OP'; /*TIPO DE OPERAO INFORMADA NVLIDA*/
                  RETURN;
               END;
            END;
         END;
      END;
      ELSE BEGIN
         IF @V_ENTRSAIDOP = 'S' BEGIN
            SET @V_CLIEFORN = @V_CDCLIENTE;
            SET @V_CDFILIEMIRECE = @V_CDFILIEMIT;
            /*VERIFICA SE A NOTA FISCAL  DE PEDIDO*/
            IF @V_IDSISTEMA = 'EXP' BEGIN
               SELECT DISTINCT @V_CDFILPEDIDO = MAX(CDFILIALPED),
                      @V_NRPEDIDO = MAX(NRPEDIDO)
                 FROM ITEMPRODUTO
                WHERE (CDFILIAL = @P_CDFILIAL)  AND
                      (NRLANCTONF = @P_NRLANCTONF)  AND
                      (CDFILIALPED IS NOT NULL);
               IF NOT (@V_NRPEDIDO IS NULL) BEGIN
                  SET @V_ENTRSAIDOP = 'P';
               END;
            END;
            /*OPERAO DE LANAMENTO DE NOTA FISCAL*/
            IF @P_IDOPERACAO = 'L' BEGIN
               IF (@V_TPOP_IDUTILVENC <> 'N') OR
                  (@V_TPOP_IDGERAVENC <> 'N') BEGIN
                  /*GERA OS VENCIMENTOS SEGUNDO FORMA DE PAGAMENTO*/
                  EXEC CRIA_VENCIMENTO @P_CDFILIAL,
                                       @P_NRLANCTONF,
                                       @V_ENTRSAIDOP,
                                       @V_VRNOTAFISC,
                                       @V_DTEMISSAO,
                                       @V_DTENTRSAID,
                                       @V_CLIEFORN,
                                       @V_CDFILIEMIRECE,
                                       @V_ORIGDESTNF,
                                       @V_CDFILLANC,
                                       @V_CDFILDEST,
                                       @V_NRAUTOFORN,
                                       @V_CDFILPEDIDO,
                                       @V_NRPEDIDO;  

                  /*INSERE A CONTA A RECEBER DE ACORDO COM OS VENCIMENTOS GERADOS*/
                  /*TRAB_VENCIMENTO : TABELA TEMPORRIA PREENCHIDA PELA CRIA_VENCIMENTO*/
                  DECLARE C_ITEMTRAB CURSOR FOR
                   SELECT DTVENCIMENTO, VRVENCIMENTO, QTDIASVENC, NRSEQVENC, IDTPCONTATRABVEN
                     FROM TRAB_VENCIMENTO
                    WHERE CDFILIALVENC = @P_CDFILIAL
                      AND NRLANCTONFVENC = @P_NRLANCTONF
                    ORDER BY NRSEQVENC;
                  OPEN C_ITEMTRAB;
                  FETCH NEXT FROM C_ITEMTRAB INTO
                  @V_ITEM_DTVENCIMENTO,
                  @V_ITEM_VRPAGO,
                  @V_ITEM_QTDIAS,
                  @V_ITEM_NRSEQUENCIAL,
                  @V_ITEM_IDTPCONTATRABVEN;

                  WHILE (@@FETCH_STATUS = 0) BEGIN
                     /*INSERE OS VENCIMENTOS NA TABELA DE CONTAS A RECEBER*/
                     INSERT INTO CONTARECEBER (CDFILIAL, NRLANCTONF, CDMOTIPROR, CDMOTIPARC, CDTPCTRECEB, NRSEQVENREC,
                                               NRPARCELAREC, QTDIASVENREC, DTORIGVENREC, VRORIGREC, DTATUAVENREC, VRATUAREC,
                                               IDSTATREC, DSCONTAREC, CDFILIBOLREC, NRLANBOLREC, IDCONTAIMPOSTO)

                     VALUES (@P_CDFILIAL, @P_NRLANCTONF, NULL, NULL, NULL, SUBSTRING(@V_ITEM_NRSEQUENCIAL, LEN(@V_ITEM_NRSEQUENCIAL)-1, 2), '00', @V_ITEM_QTDIAS, @V_ITEM_DTVENCIMENTO,
                             @V_ITEM_VRPAGO, @V_ITEM_DTVENCIMENTO, @V_ITEM_VRPAGO, 'A', NULL, NULL, NULL, @V_ITEM_IDTPCONTATRABVEN);
                     FETCH NEXT FROM C_ITEMTRAB INTO
                     @V_ITEM_DTVENCIMENTO,
                     @V_ITEM_VRPAGO,
                     @V_ITEM_QTDIAS,
                     @V_ITEM_NRSEQUENCIAL,
                     @V_ITEM_IDTPCONTATRABVEN;
                  END;
                  CLOSE C_ITEMTRAB;
                  DEALLOCATE C_ITEMTRAB;
               END;     
            END
            ELSE BEGIN
               /*OPERAO DE TRANSFERNCIA DE NOTA FISCAL ELETRNICA*/
               IF @P_IDOPERACAO = 'T' BEGIN
                  /*REGERA VENCIMENTOS SEGUNDO FORMA DE PAGAMENTO*/
                  EXEC CRIA_VENCIMENTO @P_CDFILIAL,
                                       @P_NRLANCTONF,
                                       @V_ENTRSAIDOP,
                                       @V_VRNOTAFISC,
                                       @V_DTEMISSAO,
                                       @V_DTENTRSAID,
                                       @V_CLIEFORN,
                                       @V_CDFILIEMIRECE,
                                       @V_ORIGDESTNF,
                                       @V_CDFILLANC,
                                       @V_CDFILDEST,
                                       @V_NRAUTOFORN,
                                       @V_CDFILPEDIDO,
                                       @V_NRPEDIDO;

                  /*BUSCA TIPO DE CONTA PARA SUBST. TRUBUTARIA*/
                 SELECT @V_TPCTSUBTRIB = CDTPCTRECEB
                   FROM PARAMFILIAL
                  WHERE CDFILIAL = @P_CDFILIAL;

                  /*BUSCA OS VENCIMENTOS GERADOS PELA CRIA_VENCIMENTO*/
                  DECLARE C_ITEMTRAB CURSOR FOR
                   SELECT DTVENCIMENTO, VRVENCIMENTO, QTDIASVENC, NRSEQVENC, IDTPCONTATRABVEN
                     FROM TRAB_VENCIMENTO
                    WHERE CDFILIALVENC = @P_CDFILIAL
                      AND NRLANCTONFVENC = @P_NRLANCTONF
                    ORDER BY NRSEQVENC;
                  OPEN C_ITEMTRAB;
                  FETCH NEXT FROM C_ITEMTRAB INTO
                  @V_ITEM_DTVENCIMENTO,
                  @V_ITEM_VRPAGO,
                  @V_ITEM_QTDIAS,
                  @V_ITEM_NRSEQUENCIAL,
                  @V_ITEM_IDTPCONTATRABVEN;
                  WHILE (@@FETCH_STATUS = 0) BEGIN
                     SELECT @V_NRSEQVENREC = MAX(NRSEQVENREC), @V_DSCONTAREC = MAX(DSCONTAREC), @V_DTVENREC = MAX(DTORIGVENREC), @V_VRCONTREC = MAX(VRATUAREC)
                       FROM CONTARECEBER
                      WHERE CDFILIAL = @P_CDFILIAL
                        AND NRLANCTONF = @P_NRLANCTONF
                        AND NRSEQVENREC = SUBSTRING(@V_ITEM_NRSEQUENCIAL, LEN(@V_ITEM_NRSEQUENCIAL) - 1, 2)
                        AND NRPARCELAREC = '00';
                     IF (@V_QTCONTA = 0) OR NOT (@V_NRSEQVENREC IS NULL) BEGIN
                        /*VERIFICA SE O VENCIMENTO J FOI PREENCHIDO NA CONTA*/
                        IF @V_DTVENREC IS NULL BEGIN
                           SET @V_DTVENREC = @V_ITEM_DTVENCIMENTO;
                        END;

                        IF @V_VRCONTREC IS NULL BEGIN
                           SET @V_VRCONTREC = @V_ITEM_VRPAGO;
                        END;

                        /*SE O DOCUMENTO NO POSSUIR CONTAS, INSERE VENCIMENTO GERADO*/
                        IF (@V_ITEM_IDTPCONTATRABVEN = 'S') BEGIN
                           SET @V_CDTPCTREC = @V_TPCTSUBTRIB;
                        END
                        ELSE BEGIN
                           SET @V_CDTPCTREC = NULL;
                        END;
                        
                        IF (@V_QTCONTA = 0) BEGIN
                           /*INSERE A CONTA A RECEBER*/
                           INSERT INTO CONTARECEBER (CDFILIAL, NRLANCTONF, CDMOTIPROR, CDMOTIPARC, CDTPCTRECEB, NRSEQVENREC,
                                                     NRPARCELAREC, QTDIASVENREC, DTORIGVENREC, VRORIGREC, DTATUAVENREC, VRATUAREC,
                                                     IDSTATREC, DSCONTAREC, CDFILIBOLREC, NRLANBOLREC, IDCONTAIMPOSTO)
                           VALUES (@P_CDFILIAL, @P_NRLANCTONF, NULL, NULL, @V_CDTPCTREC, SUBSTRING(@V_ITEM_NRSEQUENCIAL, LEN(@V_ITEM_NRSEQUENCIAL)-1, 2), '00',
                                   @V_ITEM_QTDIAS, @V_DTVENREC, @V_VRCONTREC, @V_DTVENREC,
                                   @V_VRCONTREC, 'A', NULL, NULL, NULL, @V_ITEM_IDTPCONTATRABVEN);
                        END
                        /*SE O DOCUMENTO POSSUIR CONTAS E FOI ENCONTRADA A CONTA COM O SEQUENCIAL EM QUESTO,
                        ATUALIZA A CONTA A RECEBER COM O VENCIMENTO CALCULADO*/
                        ELSE BEGIN
                           UPDATE CONTARECEBER
                              SET DTORIGVENREC = @V_DTVENREC,
                                  DTATUAVENREC = @V_DTVENREC,
                                  DSCONTAREC = SUBSTRING(@V_DESCRICAO, 1, 200),
                                  CDTPCTRECEB = @V_CDTPCTREC
                            WHERE CDFILIAL = @P_CDFILIAL
                              AND NRLANCTONF = @P_NRLANCTONF
                              AND NRSEQVENREC = @V_NRSEQVENREC;
                        END;
                        SET @V_COUNT = @V_COUNT + 1;
                     END;
                     FETCH NEXT FROM C_ITEMTRAB INTO
                     @V_ITEM_DTVENCIMENTO,
                     @V_ITEM_VRPAGO,
                     @V_ITEM_QTDIAS,
                     @V_ITEM_NRSEQUENCIAL,
                     @V_ITEM_IDTPCONTATRABVEN;
                  END;
                  CLOSE C_ITEMTRAB;
                  DEALLOCATE C_ITEMTRAB;
               END
               ELSE BEGIN
                  /*OPERAO DE APROVAO DA NOTA FISCAL*/
                  IF @P_IDOPERACAO = 'A' BEGIN
                     /*BUSCA PARAMETRIZAO DE TIPO DE CONTA POR PRODUTO*/
                     SELECT @V_CDTPCTRECEB = TR.CDTPCTRECEB,
                            @V_CDCLASSFINA = TR.CDCLASSFINA
                       FROM (SELECT MAX(CDARVPROD) AS CDARVPROD
                               FROM ITEMPRODUTO I, PRODUTO P
                              WHERE CDFILIAL    = @P_CDFILIAL AND
                                    NRLANCTONF  = @P_NRLANCTONF AND
                                    I.CDPRODUTO = P.CDPRODUTO
                              GROUP BY VRTOTAITEM
                              HAVING VRTOTAITEM = (SELECT MAX(VRTOTAITEM)
                                                   FROM ITEMPRODUTO
                                                   WHERE CDFILIAL    = @P_CDFILIAL AND
                                                         NRLANCTONF  = @P_NRLANCTONF)) IT,
                              PRODUTO PR , TIPOCTRECEBER TR
                        WHERE TR.CDTPCTRECEB = PR.CDTPCTRECEB AND
                              PR.CDARVPROD = (SELECT MAX(P.CDARVPROD)
                                                FROM TIPOCTRECEPROD C, PRODUTO P
                                               WHERE C.CDPRODUTO = P.CDPRODUTO AND
                                                     (CHARINDEX(RTRIM(P.CDARVPROD), IT.CDARVPROD) = 1));
                     /*REGERA VENCIMENTOS SEGUNDO FORMA DE PAGAMENTO*/
                     EXEC CRIA_VENCIMENTO @P_CDFILIAL,
                                          @P_NRLANCTONF,
                                          @V_ENTRSAIDOP,
                                          @V_VRNOTAFISC,
                                          @V_DTEMISSAO,
                                          @V_DTENTRSAID,
                                          @V_CLIEFORN,
                                          @V_CDFILIEMIRECE,
                                          @V_ORIGDESTNF,
                                          @V_CDFILLANC,
                                          @V_CDFILDEST,
                                          @V_NRAUTOFORN,
                                          @V_CDFILPEDIDO,
                                          @V_NRPEDIDO;

                     /*BUSCA TIPO DE CONTA PARA SUBST. TRUBUTARIA*/
                     SELECT @V_TPCTSUBTRIB = CDTPCTRECEB
                       FROM PARAMFILIAL
                      WHERE CDFILIAL = @P_CDFILIAL;
                      
                     IF @V_CDTPCTRECEB IS NULL BEGIN
                        /*TIPO DE CONTA PARAMETRIZADO NO TIPO DE OPERAO*/
                        SET @V_CDTPCTRECEB = @V_TPOP_CDTPCTRECEB;
                     END;
                     /*CLASSFICAO FINANCEIRA DO TIPO DE CONTA*/
                     SELECT @V_CDCLASSFINA = CDCLASSFINA
                       FROM TIPOCTRECEBER
                      WHERE CDTPCTRECEB = @V_CDTPCTRECEB;

                     SET @V_COUNT = 0;
                     /*VERIFICA SE O DOCUMENTO POSSUI CONTAS A RECEBER*/
                     SELECT @V_QTCONTA = COUNT(*)
                       FROM CONTARECEBER
                      WHERE CDFILIAL = @P_CDFILIAL
                        AND NRLANCTONF = @P_NRLANCTONF;

                     /*BUSCA OS VENCIMENTOS GERADOS PELA CRIA_VENCIMENTO*/
                     DECLARE C_ITEMTRAB CURSOR FOR
                      SELECT DTVENCIMENTO, VRVENCIMENTO, QTDIASVENC, NRSEQVENC, IDTPCONTATRABVEN
                        FROM TRAB_VENCIMENTO
                       WHERE CDFILIALVENC = @P_CDFILIAL
                         AND NRLANCTONFVENC = @P_NRLANCTONF
                       ORDER BY NRSEQVENC;
                     OPEN C_ITEMTRAB;
                     FETCH NEXT FROM C_ITEMTRAB INTO
                     @V_ITEM_DTVENCIMENTO,
                     @V_ITEM_VRPAGO,
                     @V_ITEM_QTDIAS,
                     @V_ITEM_NRSEQUENCIAL,
                     @V_ITEM_IDTPCONTATRABVEN;
                     WHILE (@@FETCH_STATUS = 0) BEGIN
                        SELECT @V_NRSEQVENREC = MAX(NRSEQVENREC), @V_DSCONTAREC = MAX(DSCONTAREC), @V_DTVENREC = MAX(DTORIGVENREC), @V_VRCONTREC = MAX(VRATUAREC)
                          FROM CONTARECEBER
                         WHERE CDFILIAL = @P_CDFILIAL
                           AND NRLANCTONF = @P_NRLANCTONF
                           AND NRSEQVENREC = SUBSTRING(@V_ITEM_NRSEQUENCIAL, LEN(@V_ITEM_NRSEQUENCIAL) - 1, 2)
                           AND NRPARCELAREC = '00';

                        /*SE O DOCUMENTO NO POSSUIR CONTAS, INSERE VENCIMENTO GERADO*/
                        IF (@V_ITEM_IDTPCONTATRABVEN = 'S') BEGIN
                           SET @V_CDTPCTREC = @V_TPCTSUBTRIB;
                        END
                        ELSE BEGIN
                           SET @V_CDTPCTREC = NULL;
                        END;

                        IF (@V_QTCONTA = 0) OR NOT (@V_NRSEQVENREC IS NULL) BEGIN
                           IF @V_DSCONTAREC IS NULL BEGIN
                              /*MONTA HISTRICO PARA A CONTA*/
                              SELECT @V_NF_CDFILIAL = NF.CDFILIAL,
                                     @V_NF_NRLANCTONF = NF.NRLANCTONF,
                                     @V_NF_NRNOTAFISC = NF.NRNOTAFISC,
                                     @V_NF_NRINSJURCLIE = C.NRINSJURCLIE,
                                     @V_NF_IDTPIJURCLIE = C.IDTPIJURCLIE,
                                     @V_NF_NMFANTCLIE = C.NMFANTCLIE,
                                     @V_NF_NMRAZSOCCLIE = C.NMRAZSOCCLIE,
                                     @V_NF_NRINSJURFORN = F.NRINSJURFORN,
                                     @V_NF_IDTPIJURFORN = F.IDTPIJURFORN,
                                     @V_NF_NMFANTFORN = F.NMFANTFORN,
                                     @V_NF_NMRAZSOCFORN = F.NMRAZSOCFORN,
                                     @V_NF_DTEMISSAO = NF.DTEMISSAO,
                                     @V_NF_DTENTRSAID = NF.DTENTRSAID,
                                     @V_NF_CDSERIEENTR = NF.CDSERIEENTR
                                FROM NOTAFISCAL NF LEFT JOIN CLIENTE C
                                     ON NF.CDCLIENTE  = C.CDCLIENTE
                                     LEFT JOIN FORNECEDOR F
                                     ON NF.CDFORNECED = F.CDFORNECED
                               WHERE CDFILIAL = @P_CDFILIAL AND
                                     NRLANCTONF = @P_NRLANCTONF;

                              /*BUSCA A DESCRIO PADRO DO HISTRICO*/
                              SELECT @V_DESCRICAO = DSHISTPADR
                                FROM HISTPADR
                               WHERE CDHISTPADR = @V_TPOP_CDHISTPADR;
                              /*BUSCA DESCRIO DO ITEM DE PRODUTO*/
                              SELECT @V_NF_DSPRODEMIS = MAX(CONVERT(VARCHAR, DSPRODEMIS, 400))
                                FROM ITEMPRODUTO
                               WHERE CDFILIAL   = @P_CDFILIAL AND
                                     NRLANCTONF = @P_NRLANCTONF;

                              /*SUBSTITUIO DOS MNEUMNICOS PELOS VALORES CORRESPONDENTES*/
                              SET @V_DESCRICAO = REPLACE(@V_DESCRICAO, '[DOC]', ISNULL(@V_NF_NRNOTAFISC, ''));
                              SET @V_DESCRICAO = REPLACE(@V_DESCRICAO, '[FIL]', ISNULL(@V_NF_CDFILIAL, ''));
                              SET @V_DESCRICAO = REPLACE(@V_DESCRICAO, '[SEQ]', ISNULL(@V_NF_NRLANCTONF, ''));
                              SET @V_DESCRICAO = REPLACE(@V_DESCRICAO, '[CLI]', ISNULL(@V_NF_NRINSJURCLIE, ''));
                              SET @V_DESCRICAO = REPLACE(@V_DESCRICAO, '[NFC]', ISNULL(@V_NF_NMFANTCLIE, ''));
                              SET @V_DESCRICAO = REPLACE(@V_DESCRICAO, '[RSC]', ISNULL(@V_NF_NMRAZSOCCLIE, ''));
                              SET @V_DESCRICAO = REPLACE(@V_DESCRICAO, '[FOR]', ISNULL(@V_NF_NRINSJURFORN, ''));
                              SET @V_DESCRICAO = REPLACE(@V_DESCRICAO, '[NFF]', ISNULL(@V_NF_NMFANTFORN, ''));
                              SET @V_DESCRICAO = REPLACE(@V_DESCRICAO, '[NMPR]', ISNULL(@V_NF_DSPRODEMIS, ''));
                              SET @V_DESCRICAO = REPLACE(@V_DESCRICAO, '[DTEM-MA]',
                              ISNULL(RIGHT(REPLICATE('0',2) + CONVERT(VARCHAR, MONTH(@V_NF_DTEMISSAO)), 2) + '/' +
                              RIGHT(REPLICATE('0',4) + CONVERT(VARCHAR, YEAR(@V_NF_DTEMISSAO)), 4), ''));
                              SET @V_DESCRICAO = REPLACE(@V_DESCRICAO, '[DTES-MA]',
                              ISNULL(RIGHT(REPLICATE('0',2) + CONVERT(VARCHAR, MONTH(@V_NF_DTENTRSAID)), 2) + '/' +
                              RIGHT(REPLICATE('0',4) + CONVERT(VARCHAR, YEAR(@V_NF_DTENTRSAID)), 4), ''));
                              SET @V_DESCRICAO = REPLACE(@V_DESCRICAO, '[DTEM]', ISNULL(CONVERT(VARCHAR, @V_NF_DTEMISSAO, 103), ''));
                              SET @V_DESCRICAO = REPLACE(@V_DESCRICAO, '[DTES]', ISNULL(CONVERT(VARCHAR, @V_NF_DTENTRSAID,103), ''));
                           END
                           ELSE BEGIN
                              SET @V_DESCRICAO = @V_DSCONTAREC;
                           END;

                           IF @V_DTVENREC IS NULL BEGIN
                              SET @V_DTVENREC = @V_ITEM_DTVENCIMENTO;
                           END;

                           IF @V_VRCONTREC IS NULL BEGIN
                              SET @V_VRCONTREC = @V_ITEM_VRPAGO;
                           END;

                           /*ATUALIZA FLUXO DE CAIXA DO AJUSTE*/
                           EXEC ATUALIZA_FLUXO_DE_CAIXA @V_CDEMPRESA,
                                                        @V_CDFILIEMIT,
                                                        @V_DTVENREC,
                                                        'E',
                                                        @V_CDCLASSFINA,
                                                        @V_VRCONTREC,
                                                        0;
                           /*SE O DOCUMENTO NO POSSUIR CONTAS, INSERE VENCIMENTO GERADO*/
                           IF (@V_QTCONTA = 0) BEGIN
                              /*INSERE A CONTA A RECEBER*/
                              INSERT INTO CONTARECEBER (CDFILIAL, NRLANCTONF, CDMOTIPROR, CDMOTIPARC, CDTPCTRECEB, NRSEQVENREC,
                                                        NRPARCELAREC, QTDIASVENREC, DTORIGVENREC, VRORIGREC, DTATUAVENREC, VRATUAREC,
                                                        IDSTATREC, DSCONTAREC, CDFILIBOLREC, NRLANBOLREC, IDCONTAIMPOSTO)
                              VALUES (@P_CDFILIAL, @P_NRLANCTONF, NULL, NULL, @V_CDTPCTREC, SUBSTRING(@V_ITEM_NRSEQUENCIAL, LEN(@V_ITEM_NRSEQUENCIAL)-1, 2), '00',
                                      @V_ITEM_QTDIAS, @V_DTVENREC, @V_VRCONTREC, @V_DTVENREC,
                                      @V_VRCONTREC, 'A', SUBSTRING(@V_DESCRICAO, 1, 200), NULL, NULL, @V_ITEM_IDTPCONTATRABVEN);
                           END
                           /*SE O DOCUMENTO POSSUIR CONTAS E FOI ENCONTRADA A CONTA COM O SEQUENCIAL EM QUESTO*/
                           ELSE BEGIN
                              UPDATE CONTARECEBER
                                 SET DTORIGVENREC = @V_DTVENREC,
                                     DTATUAVENREC = @V_DTVENREC,
                                     DSCONTAREC = SUBSTRING(@V_DESCRICAO, 1, 200),
                                     CDTPCTRECEB = @V_CDTPCTREC
                               WHERE CDFILIAL = @P_CDFILIAL
                                 AND NRLANCTONF = @P_NRLANCTONF
                                 AND NRSEQVENREC = @V_NRSEQVENREC;
                           END;
                           SET @V_COUNT = @V_COUNT + 1;
                        END;
                        FETCH NEXT FROM C_ITEMTRAB INTO
                        @V_ITEM_DTVENCIMENTO,
                        @V_ITEM_VRPAGO,
                        @V_ITEM_QTDIAS,
                        @V_ITEM_NRSEQUENCIAL,
                        @V_ITEM_IDTPCONTATRABVEN;
                     END;
                     CLOSE C_ITEMTRAB;
                     DEALLOCATE C_ITEMTRAB;

                     IF @V_QTCONTA > @V_COUNT BEGIN
                        SET @V_COUNT = @V_QTCONTA;
                     END;
                     IF (@V_COUNT > 0) BEGIN
                        SET @V_CHAVE = 'BOLETRECEBER'+@P_CDFILIPROC;
                        EXEC NOVO_CODIGO @V_CHAVE, @V_NRLANBOL OUTPUT, @V_COUNT ; /*BUSCA O NMERO DO PRXIMO BOLETO*/
                        SET @V_NRLANBOL = SUBSTRING(@V_NRLANBOL, LEN(@V_NRLANBOL) - 9, 10);
                        /*GERAO DOS BOLETOS A RECEBER*/
                        EXEC GERA_BOLETOS @P_CDFILIAL, @P_NRLANCTONF, @P_CDFILIPROC, @V_NRLANBOL, @V_CDTPCTRECEB, NULL, NULL, NULL;
                        /*GERA RATEIO DAS CONTAS A RECEBER*/
                        /*GERA RATEIO DAS CONTAS A PAGAR*/
                        /*APAGA, CASO EXISTA, OS RATEIOS DA CONTA A RECEBER DA NOTA FISCAL*/
                        DELETE FROM RATCTRECEBER
                         WHERE CDFILIAL = @P_CDFILIAL
                           AND NRLANCTONF = @P_NRLANCTONF;
                        /*BUSCA AS CONTAS RELACIONADAS  NOTA FISCAL E INSERE RATEIO PARA CADA UMA DELAS*/
                        DECLARE C_CTREC CURSOR FOR
                        SELECT CDFILIAL, NRLANCTONF, NRSEQVENREC, NRPARCELAREC, VRATUAREC, CDTPCTRECEB
                          FROM CONTARECEBER
                         WHERE CDFILIAL = @P_CDFILIAL
                           AND NRLANCTONF = @P_NRLANCTONF;
                        OPEN C_CTREC;
                        FETCH NEXT FROM C_CTREC INTO
                        @V_CNT_CDFILIAL,
                        @V_CNT_NRLANCTONF,
                        @V_CNT_NRSEQVENREC,
                        @V_CNT_NRPARCELAREC,
                        @V_CNT_VRATUAREC,
                        @V_CNT_CDTPCTRECEB;

                        WHILE (@@FETCH_STATUS = 0) BEGIN
                           SET @V_COUNT = 1;
                           SET @V_VRACUMULADO = 0;

                           SELECT @V_NRPARCELA = COUNT(*)
                             FROM LANCCCUSTO LC, LANCCONT L
                            WHERE L.CDEMPRESA   = @V_CDEMPRESA AND
                                  L.NRLANCCONT  = @V_NRLANCCONT AND
                                  LC.CDEMPRESA  = L.CDEMPRESA AND
                                  LC.NRLANCCONT = L.NRLANCCONT AND
                                  LC.NRSEQLANC  = L.NRSEQLANC AND
                                  LC.NRSEQLANC  = (SELECT MAX(NRSEQLANC)
                                                     FROM LANCCONT
                                                    WHERE CDEMPRESA = @V_CDEMPRESA
                                                      AND NRLANCCONT = @V_NRLANCCONT);

                           IF @V_NRPARCELA > 0 BEGIN
                              DECLARE C_LANCCUST CURSOR FOR
                              SELECT LC.CDCENTCUST, LC.CDFILIAL,
                                       (ABS(SUM(LC.VRLANCCUST))/CASE ABS(SUM(L.VRLANCAMENT)) WHEN 0 THEN 1 ELSE ABS(SUM(L.VRLANCAMENT)) END)
                                       AS VRPARCRATEIO
                                  FROM LANCCCUSTO LC, LANCCONT L
                                 WHERE L.CDEMPRESA   = @V_CDEMPRESA AND
                                       L.NRLANCCONT  = @V_NRLANCCONT AND
                                       LC.CDEMPRESA  = L.CDEMPRESA AND
                                       LC.NRLANCCONT = L.NRLANCCONT AND
                                       LC.NRSEQLANC  = L.NRSEQLANC AND
                                       LC.NRSEQLANC  = (SELECT MAX(NRSEQLANC)
                                                          FROM LANCCONT
                                                         WHERE CDEMPRESA = @V_CDEMPRESA
                                                           AND NRLANCCONT = @V_NRLANCCONT)
                                 GROUP BY LC.CDCENTCUST, LC.CDFILIAL;

                              OPEN C_LANCCUST;
                              FETCH NEXT FROM C_LANCCUST INTO
                              @V_CDCENTCUST,
                              @V_CDFILIAL,
                              @V_VRRATEIOCTB;

                              WHILE (@@FETCH_STATUS = 0) BEGIN
                                 SET @V_VRPARCELA = ROUND((@V_CNT_VRATUAREC * @V_VRRATEIOCTB),2);
                                 SET @V_VRACUMULADO = @V_VRACUMULADO + @V_VRPARCELA;
                                 IF @V_COUNT = @V_NRPARCELA  BEGIN
                                    SET @V_VRPARCELA = @V_VRPARCELA + ROUND(@V_CNT_VRATUAREC - @V_VRACUMULADO,2);
                                 END;
                                 IF NOT (@V_CDFILIAL IS NULL) AND NOT (@V_CDCENTCUST IS NULL) BEGIN
                                    SELECT @V_ROW_COUNT = COUNT(*)
                                      FROM CENTCUSTFIL
                                     WHERE CDFILIAL = @V_CDFILIAL
                                       AND CDCENTCUST = @V_CDCENTCUST;
                                    IF @V_ROW_COUNT > 0 BEGIN
                                       /*INSERE RATEIO PARA A CONTA A RECEBER*/
                                       INSERT INTO RATCTRECEBER
                                          (CDFILIAL, NRLANCTONF, NRSEQVENREC, NRPARCELAREC,
                                           CDCENTCUST, CDFIRATCTREC, VRRATCCCTREC)
                                       VALUES
                                          (@V_CNT_CDFILIAL, @V_CNT_NRLANCTONF, @V_CNT_NRSEQVENREC, @V_CNT_NRPARCELAREC,
                                           @V_CDCENTCUST, @V_CDFILIAL, @V_VRPARCELA);
                                    END
                                    ELSE BEGIN
                                       /*CENTRO DE CUSTO (CDCENTCUST) NO CADASTRADO PARA A FILIAL (CDFILIAL)*/
                                       SET @P_RESULTADO = 'NOT_CENTCUSTFIL_' + @V_CDCENTCUST + @V_CDFILIAL;
                                       RETURN;
                                    END;
                                 END;
                                 SET @V_COUNT = @V_COUNT + 1;

                                 FETCH NEXT FROM C_LANCCUST INTO
                                 @V_CDCENTCUST,
                                 @V_CDFILIAL,
                                 @V_VRRATEIOCTB;
                              END;
                              CLOSE C_LANCCUST;
                              DEALLOCATE C_LANCCUST;
                           END
                           ELSE BEGIN
                              SELECT @V_NRPARCELA = COUNT(*)
                                FROM RATTPCTR
                               WHERE CDTPCTRECEB = @V_CNT_CDTPCTRECEB;
                              IF @V_NRPARCELA > 0 BEGIN
                                 DECLARE C_RATTPCTR CURSOR FOR
                                 SELECT CDTPCTRECEB, CDCENTCUST,
                                        (CASE CDFIRATTPCTR WHEN '----' THEN @V_CDFILIEMIT ELSE CDFIRATTPCTR END) AS CDFIRATTPCTR,
                                        CDFILIAL, (VRPERATTPCTR/100) AS VRPERATTPCTR
                                   FROM RATTPCTR
                                  WHERE CDTPCTRECEB = @V_CNT_CDTPCTRECEB;
                                 OPEN C_RATTPCTR;
                                 FETCH NEXT FROM C_RATTPCTR INTO
                                 @V_RAT_CDTPCONTA,
                                 @V_RAT_CDCENTCUST,
                                 @V_RAT_CDFIRATTPCT,
                                 @V_RAT_CDFILIAL,
                                 @V_RAT_VRPERATTPCT;
                                 /*BUSCA INFORMAES DO PARMETRO PARA CENTRO DE CUSTO*/
                                 WHILE (@@FETCH_STATUS = 0) BEGIN
                                    SET @V_VRPARCELA = ROUND((@V_CNT_VRATUAREC * @V_RAT_VRPERATTPCT),2);
                                    SET @V_VRACUMULADO = @V_VRACUMULADO + @V_VRPARCELA;
                                    IF @V_COUNT = @V_NRPARCELA BEGIN
                                       SET @V_VRPARCELA = @V_VRPARCELA + ROUND(@V_CNT_VRATUAREC - @V_VRACUMULADO,2);
                                    END;
                                    IF NOT (@V_RAT_CDFIRATTPCT IS NULL) AND NOT (@V_RAT_CDCENTCUST IS NULL) BEGIN
                                       SELECT @V_ROW_COUNT = COUNT(*)
                                         FROM CENTCUSTFIL
                                        WHERE CDFILIAL = @V_RAT_CDFIRATTPCT
                                          AND CDCENTCUST = @V_RAT_CDCENTCUST;
                                       IF @V_ROW_COUNT > 0 BEGIN
                                          /*INSERE RATEIO PARA A CONTA A PAGAR*/
                                          INSERT INTO RATCTRECEBER
                                             (CDFILIAL, NRLANCTONF, NRSEQVENREC, NRPARCELAREC,
                                              CDCENTCUST, CDFIRATCTREC, VRRATCCCTREC)
                                          VALUES
                                             (@V_CNT_CDFILIAL, @V_CNT_NRLANCTONF, @V_CNT_NRSEQVENREC, @V_CNT_NRPARCELAREC,
                                              @V_RAT_CDCENTCUST, @V_RAT_CDFIRATTPCT, @V_VRPARCELA);
                                       END
                                       ELSE BEGIN
                                          /*CENTRO DE CUSTO (CDCENTCUST) NO CADASTRADO PARA A FILIAL (CDFILIAL)*/
                                          SET @P_RESULTADO = 'NOT_CENTCUSTFIL_' + @V_RAT_CDCENTCUST + @V_RAT_CDFIRATTPCT;
                                          RETURN;
                                       END;
                                    END;
                                    SET @V_COUNT = @V_COUNT + 1;
                                    FETCH NEXT FROM C_RATTPCTR INTO
                                    @V_RAT_CDTPCONTA,
                                    @V_RAT_CDCENTCUST,
                                    @V_RAT_CDFIRATTPCT,
                                    @V_RAT_CDFILIAL,
                                    @V_RAT_VRPERATTPCT;
                                 END;
                                 CLOSE C_RATTPCTR;
                                 DEALLOCATE C_RATTPCTR;
                              END
                              ELSE BEGIN
                                 /*BUSCA O CENTRO DE CUSTO DA FILIAL. SE NO PARAMETRIZADO, PEGA O DA EMPRESA*/
                                 SELECT @V_CDFILIAL = MAX(CDFILIAL),
                                        @V_CDCENTCUST = MAX(CDCENTCUST)
                                   FROM
                                   (SELECT F.CDFILIAL, ISNULL(F.CDCENTCUST, E.CDCENTCUST) AS CDCENTCUST
                                     FROM FILIAL F, EMPRESA E
                                    WHERE F.CDFILIAL   = @V_CDFILIEMIT AND
                                          E.CDEMPRESA  = @V_CDEMPRESA  AND
                                          F.CDEMPRESA  = E.CDEMPRESA
                                    UNION
                                   SELECT F.CDFILIAL, ISNULL(F.CDCENTCUST, E.CDCENTCUST) AS CDCENTCUST
                                     FROM FILIAL F, EMPRESA E, EMPRCNTRFIL EC
                                    WHERE EC.CDFILIAL   = @V_CDFILIEMIT AND
                                          EC.CDEMPRESA  = @V_CDEMPRESA  AND
                                          E.CDEMPRESA   = EC.CDEMPRESA AND
                                          F.CDFILIAL = EC.CDFILIAL) SS;
                                 SET @V_VRPARCELA = @V_CNT_VRATUAREC;
                                 IF NOT (@V_CDFILIAL IS NULL) AND NOT (@V_CDCENTCUST IS NULL) BEGIN
                                    SELECT @V_ROW_COUNT = COUNT(*)
                                      FROM CENTCUSTFIL
                                     WHERE CDFILIAL = @V_CDFILIAL
                                       AND CDCENTCUST = @V_CDCENTCUST;
                                    IF (@V_ROW_COUNT > 0) BEGIN
                                       /*INSERE RATEIO DA CONTA A PAGAR*/
                                       INSERT INTO RATCTRECEBER
                                            (CDFILIAL, NRLANCTONF, NRSEQVENREC, NRPARCELAREC,
                                             CDCENTCUST, CDFIRATCTREC, VRRATCCCTREC)
                                         VALUES
                                            (@V_CNT_CDFILIAL, @V_CNT_NRLANCTONF, @V_CNT_NRSEQVENREC, @V_CNT_NRPARCELAREC,
                                             @V_CDCENTCUST, @V_CDFILIAL, @V_VRPARCELA);
                                    END
                                    ELSE BEGIN
                                       /*CENTRO DE CUSTO (CDCENTCUST) NO CADASTRADO PARA A FILIAL (CDFILIAL)*/
                                       SET @P_RESULTADO = 'NOT_CENTCUSTFIL_' + @V_CDCENTCUST + @V_CDFILIAL;
                                       RETURN;
                                    END;
                                 END;
                              END;
                           END;
                           FETCH NEXT FROM C_CTREC INTO
                           @V_CNT_CDFILIAL,
                           @V_CNT_NRLANCTONF,
                           @V_CNT_NRSEQVENREC,
                           @V_CNT_NRPARCELAREC,
                           @V_CNT_VRATUAREC,
                           @V_CNT_CDTPCTRECEB;
                        END;
                        CLOSE C_CTREC;
                        DEALLOCATE C_CTREC;
                     END;
                  END
                  ELSE BEGIN
                     SET @P_RESULTADO = 'INV_TP_OP'; /*TIPO DE OPERAO INFORMADA NVLIDA*/
                     RETURN;
                  END;
               END;
            END;
         END;
      END;

      /*APAGA OS REGISTROS CRIADOS NA TABELA AUXILIAR TRAB_VENCIMENTO*/
      DELETE FROM TRAB_VENCIMENTO
       WHERE CDFILIALVENC = @P_CDFILIAL
         AND NRLANCTONFVENC = @P_NRLANCTONF;
   END;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'GERA_DADOS_FINANCEIRO','5.85.xxx';
GO
